@@ -1,31 +1,26 @@
 package Mail::Milter::Authentication;
-# ABSTRACT: A Perl Mail Authentication Milter
-use 5.010;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: A Perl Mail Authentication Milter
+our $VERSION = '2.20200302'; # VERSION
 use base 'Net::Server::PreFork';
-our $VERSION = '2.20200206'; # VERSION
-
-
-use English qw{ -no_match_vars };
-use ExtUtils::Installed;
-use JSON;
-use Mail::Milter::Authentication::Config qw{ get_config };
-use Mail::Milter::Authentication::Constants qw{ :all };
 use Mail::Milter::Authentication::Handler;
-use Log::Dispatchouli;
 use Mail::Milter::Authentication::Metric;
 use Mail::Milter::Authentication::Protocol::Milter;
 use Mail::Milter::Authentication::Protocol::SMTP;
-use Module::Load;
-use Module::Loaded;
+use Email::Sender::Simple qw(try_to_sendmail);
+use Email::Simple::Creator;
+use Email::Simple;
+use ExtUtils::Installed;
+use Log::Dispatchouli;
 use Net::DNS::Resolver;
 use Net::IP;
 use Proc::ProcessTable;
-use Sys::Syslog qw{:standard :macros};
-
 use vars qw(@ISA);
 
+
 {
     my $LOGGER;
     sub logger {
@@ -49,21 +44,17 @@ use vars qw(@ISA);
     }
 }
 
-sub _warn {
-    my ( $msg ) = @_;
+sub _warn($msg) {
     my @parts = split "\n", $msg;
     foreach my $part ( @parts ) {
         next if $part eq q{};
         print STDERR scalar(localtime) . ' ' . $Mail::Milter::Authentication::Config::IDENT . "[$PID] $part\n";
     }
-    return;
 }
 
 
-sub preload_modules {
-    my ( $self, $from, $matching ) = @_;
+sub preload_modules($self,$from,$matching) {
     my $installed = ExtUtils::Installed->new( 'skip_cwd' => 1 );
-
     my $path_matching = $matching;
     $path_matching =~ s/::/\//g;
     foreach my $module ( grep { /$from/ } $installed->modules() ) {
@@ -82,7 +73,6 @@ sub preload_modules {
             }
         }
     }
-    return;
 }
 
 
@@ -102,8 +92,7 @@ sub get_installed_handlers {
 }
 
 
-sub write_to_log_hook {
-    my ( $self, $priority, $line ) = @_;
+sub write_to_log_hook($self,$priority,$line,@) {
     my $log_priority = $priority == 0 ? 'debug'
                      : $priority == 1 ? 'info'
                      : $priority == 2 ? 'notice'
@@ -111,24 +100,19 @@ sub write_to_log_hook {
                      : $priority == 4 ? 'error'
                      : 'debug';
     logger()->log( { 'level' => $log_priority }, $line );
-    return;
 }
 
 
-sub idle_loop_hook {
-    my ( $self ) = @_;
+sub idle_loop_hook($self,@) {
     $self->{'metric'}->master_metric_update( $self );
-    return;
 }
 
 
-sub pre_loop_hook {
-    my ( $self ) = @_;
-
+sub pre_loop_hook($self,@) {
     $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':master';
 
     $self->preload_modules( 'Net::DNS', 'Net::DNS::RR' );
-    $self->{'metric'} = Mail::Milter::Authentication::Metric->new();
+    $self->{'metric'} = Mail::Milter::Authentication::Metric->new($self);
 
     # Load handlers
     my $config = get_config();
@@ -167,17 +151,13 @@ sub pre_loop_hook {
         open( STDERR, '>>', $config->{'error_log'} ) || die "Cannot open errlog [$!]";
         open( STDOUT, '>>', $config->{'error_log'} ) || die "Cannot open errlog [$!]";
     }
-
-    return;
-
 }
 
 
-sub run_n_children_hook {
-    my ( $self ) = @_;
-
+sub run_n_children_hook($self,@) {
     # Load handlers
     my $config = get_config();
+    $self->{metric}->re_register_metrics;
     foreach my $name ( @{$config->{'load_handlers'}} ) {
 
         my $package = "Mail::Milter::Authentication::Handler::$name";
@@ -187,13 +167,10 @@ sub run_n_children_hook {
         }
 
     }
-
-    return;
 }
 
 
-sub child_init_hook {
-    my ( $self ) = @_;
+sub child_init_hook($self,@) {
     srand();
 
     my $config = get_config();
@@ -257,31 +234,25 @@ sub child_init_hook {
     $self->{'metric'}->set_versions( $self );
 
     $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':waiting(0)';
-    return;
 }
 
 
-sub child_finish_hook {
-    my ($self) = @_;
+sub child_finish_hook($self,@) {
     $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':exiting';
     $self->loginfo( "Child process $PID shutting down" );
     eval {
         $self->{'handler'}->{'_Handler'}->metric_count( 'reaped_children_total', {}, 1 );
     };
     $self->destroy_objects();
-    return;
 }
 
 
-sub pre_server_close_hook {
-    my ($self) = @_;
+sub pre_server_close_hook($self,@) {
     $self->loginfo( 'Server closing down' );
-    return;
 }
 
 
-sub get_client_proto {
-    my ( $self ) = @_;
+sub get_client_proto($self,@) {
     my $socket = $self->{server}{client};
     if ($socket->isa("Net::Server::Proto")) {
         my $proto = $socket->NS_proto;
@@ -302,34 +273,28 @@ sub get_client_proto {
     }
 
     $self->logerror( "Could not determine connection protocol: " . ref($socket) );
-
-    return;
 }
 
 
-sub get_client_port {
-    my ( $self ) = @_;
+sub get_client_port($self,@) {
     my $socket = $self->{server}{client};
     return $socket->sockport();
 }
 
 
-sub get_client_host {
-    my ( $self ) = @_;
+sub get_client_host($self,@) {
     my $socket = $self->{server}{client};
     return $socket->sockhost();
 }
 
 
-sub get_client_path {
-    my ( $self ) = @_;
+sub get_client_path($self,@) {
     my $socket = $self->{server}{client};
     return $socket->hostpath();
 }
 
 
-sub get_client_details {
-    my ( $self ) = @_;
+sub get_client_details($self,@) {
     my $proto = lc $self->get_client_proto();
     if ( $proto eq 'tcp' ) {
         return 'inet:' . $self->get_client_port();
@@ -337,12 +302,10 @@ sub get_client_details {
     elsif ( $proto eq 'unix' ) {
         return 'unix:' . $self->get_client_path();
     }
-    return;
 }
 
 
-sub process_request {
-    my ( $self ) = @_;
+sub process_request($self,@) {
     my $config = $self->{'config'};
 
     my $metric_type;
@@ -380,13 +343,10 @@ sub process_request {
 
     my $count = $self->{'count'};
     $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':waiting(' . $count . ')';
-    return;
 }
 
 
-sub process_main {
-    my ( $self ) = @_;
-
+sub process_main($self,@) {
     $self->{'count'}++;
     my $count = $self->{'count'};
     my $config = $self->{'config'};
@@ -395,14 +355,20 @@ sub process_main {
     $self->logdebug( 'Processing request ' . $self->{'count'} );
     $self->{'socket'} = $self->{'server'}->{'client'};
 
+    $self->{'tracelog'} = [];
+
     $self->protocol_process_request();
 
     # Call close callback
     $self->{'handler'}->{'_Handler'}->top_close_callback();
     if ( $self->{'handler'}->{'_Handler'}->{'exit_on_close'} ) {
-        $self->fatal('exit_on_close requested');
+        my $error = $self->{'handler'}->{'_Handler'}->{'exit_on_close_error'} // 'no reason given';
+        $self->send_exception_email($error);
+        $self->fatal('exit_on_close requested - '.$error);
     }
 
+    $self->{'tracelog'} = [];
+
     if ( $config->{'debug'} ) {
         my $process_table = Proc::ProcessTable->new();
         foreach my $process ( @{$process_table->table} ) {
@@ -420,14 +386,63 @@ sub process_main {
     delete $self->{'handler'}->{'_Handler'}->{'return_code'};
     delete $self->{'socket'};
     $self->logdebug( 'Request processing completed' );
-    return;
 }
 
 
+sub send_exception_email {
+    my ( $self, $error ) = @_;
+
+    if ( $self->{'handler'}->{'_Handler'}->{'suppress_error_emails'} ) {
+        return;
+    }
+
+    my $config         = get_config();
+    my $errors_to      = $config->{'errors_to'} || return;
+    my $errors_from    = $config->{'errors_from'} || return;
+    my $errors_headers = $config->{'errors_headers'} || {};
+
+    my $email = "Authentication Milter " . $Mail::Milter::Authentication::Config::IDENT . " Error\n\n";
+    $email .= "$error\n\n";
+
+    $email .= "Child PID: $PID\n\n";
+
+    $email .= "Log:\n";
+    $email .= join( "\n", $self->{'tracelog'}->@* );
+    $email .= "\n\n";
+
+    $email .= "Processes Running\n";
+    my $ppid = $self->{'server'}->{'ppid'};
+    my $process_table = Proc::ProcessTable->new;
+    foreach my $process ( $process_table->table->@* ) {
+        next if ! ( $process->pid == $ppid || $process->ppid == $ppid );
+        my $pid = eval{ $process->pid } // '';
+        my $cmndline = eval{ $process->cmndline } // '';
+        my $size   = eval{ $process->size } // '';
+        my $rss    = eval{ $process->rss } // '';
+        my $pctmem = eval{ $process->pctmem } // '';
+        my $pctcpu = eval{ $process->pctcpu } // '';
+        $email .= "pid:$pid, $cmndline, size:$size, mem:$rss ($pctmem%), cpu: $pctcpu%\n";
+    }
+
+    my @headers;
+    foreach my $key ( sort keys $errors_headers->%* ) {
+        push @headers, $key => $errors_headers->{$key};
+    }
+    push @headers, to => $errors_to;
+    push @headers, From => $errors_from;
+    push @headers, Subject => 'Authentication Milter Error';
+    push @headers, 'X-Authentication-Milter-Error' => 'Generated Error Report';
+
+    my $emailer = Email::Simple->create(
+        header => \@headers,
+        body => $email,
+    );
+    try_to_sendmail($emailer);
+
+}
 
 
-sub get_valid_pid {
-    my ( $pid_file ) = @_;
+sub get_valid_pid($pid_file) {
     if ( ! $pid_file ) {
         return undef; ## no critic
     }
@@ -444,7 +459,7 @@ sub get_valid_pid {
     my $found_pid  = 0;
 
     my $process_table = Proc::ProcessTable->new();
-    foreach my $process ( @{$process_table->table} ) {
+    foreach my $process ( $process_table->table->@* ) {
         if ( $process->pid == $self_pid ) {
             if ( $process->cmndline eq $Mail::Milter::Authentication::Config::IDENT . ':control' ) {
                 $found_self = 1;
@@ -473,7 +488,7 @@ sub get_valid_pid {
 
 sub find_process {
     my $process_table = Proc::ProcessTable->new();
-    foreach my $process ( @{$process_table->table} ) {
+    foreach my $process ( $process_table->table->@* ) {
         if ( $process->cmndline eq $Mail::Milter::Authentication::Config::IDENT . ':master' ) {
             return $process->pid;
         }
@@ -482,8 +497,7 @@ sub find_process {
 }
 
 
-sub control {
-    my ( $args ) = @_;
+sub control($args) {
     my $pid_file = $args->{'pid_file'};
     my $command  = $args->{'command'};
 
@@ -530,20 +544,15 @@ sub control {
     else {
         die 'unknown command';
     }
-
-    return;
 }
 
 
-sub start {
-    my ($args)     = @_;
-
+sub start($args) {
     local $SIG{__WARN__} = sub {
         foreach my $msg ( @_ ) {
             logger()->log( { level => 'warning' }, "Warning: $msg" );
             _warn( "Warning: $msg" );
         }
-        return;
     };
 
     my $config                 = get_config();
@@ -788,22 +797,18 @@ sub start {
     }
     _warn "Server exiting abnormally";
     die;
-
-    return; ## no critic
 }
 
 ##### Protocol methods
 
 
-sub fatal {
-    my ( $self, $error ) = @_;
+sub fatal($self,$error) {
     $self->logerror( "Child process $PID shutting down due to fatal error: $error" );
     die "$error\n";
 }
 
 
-sub fatal_global {
-    my ( $self, $error ) = @_;
+sub fatal_global($self,$error) {
     my $ppid = $self->{'server'}->{'ppid'};
     if ( $ppid == $PID ) {
         $self->logerror( "Global shut down due to fatal error: $error" );
@@ -816,9 +821,7 @@ sub fatal_global {
 }
 
 
-sub setup_handlers {
-    my ( $self ) = @_;
-
+sub setup_handlers($self) {
     $self->logdebug( 'setup objects' );
     my $handler = Mail::Milter::Authentication::Handler->new( $self );
     $self->{'handler'}->{'_Handler'} = $handler;
@@ -826,17 +829,14 @@ sub setup_handlers {
     $handler->metric_count( 'forked_children_total', {}, 1 );
 
     my $config = $self->{'config'};
-    foreach my $name ( @{$config->{'load_handlers'}} ) {
+    foreach my $name ( $config->{'load_handlers'}->@* ) {
         $self->setup_handler( $name );
     }
     $self->sort_all_callbacks();
-    return;
 }
 
 
-sub load_handler {
-    my ( $self, $name ) = @_;
-
+sub load_handler($self,$name) {
     ## TODO error handling here
     $self->logdebug( "Load Handler $name" );
 
@@ -848,13 +848,10 @@ sub load_handler {
             $self->fatal_global('Could not load handler ' . $name . ' : ' . $error);
         }
     }
-    return;
 }
 
 
-sub setup_handler {
-    my ( $self, $name ) = @_;
-
+sub setup_handler($self,$name) {
     ## TODO error handling here
     $self->logdebug( "Instantiate Handler $name" );
 
@@ -867,8 +864,6 @@ sub setup_handler {
             $self->register_callback( $name, $callback );
         }
     }
-
-    return;
 }
 
 
@@ -879,33 +874,26 @@ sub destroy_handler {
     delete $self->{'handler'}->{$name}->{'thischild'};
     # Remove reference to handler
     delete $self->{'handler'}->{$name};
-    return;
 }
 
 
-sub register_callback {
-    my ( $self, $name, $callback ) = @_;
+sub register_callback($self,$name,$callback) {
     $self->logdebug( "Register Callback $name:$callback" );
     if ( ! exists $self->{'callbacks'}->{$callback} ) {
         $self->{'callbacks'}->{$callback} = [];
     }
     push @{ $self->{'callbacks'}->{$callback} }, $name;
-    return;
 }
 
 
-sub sort_all_callbacks {
-    my ($self) = @_;
+sub sort_all_callbacks($self) {
     foreach my $callback ( qw { metrics setup connect helo envfrom envrcpt header eoh body eom addheader abort close } ) {
         $self->sort_callbacks( $callback );
     }
-    return;
 }
 
 
-sub sort_callbacks {
-    my ( $self, $callback ) = @_;
-
+sub sort_callbacks($self,$callback) {
     if ( ! exists $self->{'callbacks'}->{$callback} ) {
         $self->{'callbacks'}->{$callback} = [];
     }
@@ -933,7 +921,7 @@ sub sort_callbacks {
         my $requires_method = $callback . '_requires';
         if ( $handler->can( $requires_method ) ) {
             my $requires = $handler->$requires_method;
-            foreach my $require ( @{ $requires } ) {
+            foreach my $require ( $requires->@* ) {
                 push @{ $requirements->{ $item } }, $require;
             }
         }
@@ -943,7 +931,7 @@ sub sort_callbacks {
         my $requires_method = $callback . '_required_before';
         if ( $handler->can( $requires_method ) ) {
             my $requires = $handler->$requires_method;
-            foreach my $require ( @{ $requires } ) {
+            foreach my $require ( $requires->@* ) {
                 push @{ $requirements->{ $require } }, $item;
             }
         }
@@ -954,7 +942,7 @@ sub sort_callbacks {
         foreach my $item ( @todo ) {
             my $requires_met = 1;
             my $requires = $requirements->{ $item };
-            foreach my $require ( @{ $requires } ) {
+            foreach my $require ( $requires->@* ) {
                 if ( ! exists $added->{$require} ) {
                     $requires_met = 0;
                 }
@@ -977,25 +965,22 @@ sub sort_callbacks {
     }
 
     $self->{'callbacks_list'}->{$callback} = \@order;
-    return;
 }
 
 
-sub destroy_objects {
-    my ( $self ) = @_;
+sub destroy_objects($self) {
     $self->logdebug ( 'destroy objects' );
     my $handler = $self->{'handler'}->{'_Handler'};
     if ( $handler ) {
         $handler->destroy_all_objects();
         my $config = $self->{'config'};
-        foreach my $name ( @{$config->{'load_handlers'}} ) {
+        foreach my $name ( $config->{'load_handlers'}->@* )  {
             $self->destroy_handler( $name );
         }
         delete $self->{'handler'}->{'_Handler'}->{'config'};
         delete $self->{'handler'}->{'_Handler'}->{'thischild'};
         delete $self->{'handler'}->{'_Handler'};
     }
-    return;
 }
 
 
@@ -1004,8 +989,7 @@ sub destroy_objects {
 ## Logging
 
 
-sub get_queue_id {
-    my ( $self ) = @_;
+sub get_queue_id($self) {
     my $queue_id;
 
     if ( exists ( $self->{'smtp'} ) ) {
@@ -1021,8 +1005,7 @@ sub get_queue_id {
 }
 
 
-sub enable_extra_debugging {
-    my ($self) = @_;
+sub enable_extra_debugging($self) {
     my $config = $self->{'config'} || get_config();
     $config->{'logtoerr'} = 1;
     $config->{'debug'}    = 1;
@@ -1030,45 +1013,37 @@ sub enable_extra_debugging {
     $self->logerror( 'Extra debugging enabled. Child will exit on close.' );
     # We don't want to persist this, so force an exit on close state.
     $self->{'handler'}->{'_Handler'}->{'exit_on_close'} = 1;
-    return;
 }
 
 
-sub extra_debugging {
-    my ($self,$line) = @_;
+sub extra_debugging($self,$line) {
     if ( $self->{'extra_debugging'} ) {
         $self->logerror( $line );
     }
-    return;
 }
 
 
-sub logerror {
-    my ($self,$line) = @_;
+sub logerror($self,$line) {
     my $config = $self->{'config'} || get_config();
     if ( my $queue_id = $self->get_queue_id() ) {
         $line = $queue_id . ': ' . $line;
     }
     _warn( $line ) if $config->{'logtoerr'};
     logger()->log( { 'level' => 'error' }, $line );
-    return;
 }
 
 
-sub loginfo {
-    my ($self,$line) = @_;
+sub loginfo($self,$line) {
     my $config = $self->{'config'} || get_config();
     if ( my $queue_id = $self->get_queue_id() ) {
         $line = $queue_id . ': ' . $line;
     }
     _warn( $line ) if $config->{'logtoerr'};
     logger()->log( { 'level' => 'info' }, $line );
-    return;
 }
 
 
-sub logdebug {
-    my ($self,$line) = @_;
+sub logdebug($self,$line) {
     my $config = $self->{'config'} || get_config();
     if ( my $queue_id = $self->get_queue_id() ) {
         $line = $queue_id . ': ' . $line;
@@ -1077,7 +1052,6 @@ sub logdebug {
         _warn( $line ) if $config->{'logtoerr'};
         logger()->log( { 'level' => 'debug' }, $line );
     }
-    return;
 }
 
 1;
@@ -1094,7 +1068,7 @@ Mail::Milter::Authentication - A Perl Mail Authentication Milter
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 SYNOPSIS
 
@@ -1178,6 +1152,10 @@ Hook which runs for each request, passes control to metrics handler or process_m
 
 Method which runs for each request, sets up per request items and processes the request.
 
+=head2 I<send_exception_email()>
+
+Send an email to the administrator with details of a problem.
+
 =head2 I<fatal($error)>
 
 Log a fatal error and die in child
