@@ -1,17 +1,15 @@
 package Mail::Milter::Authentication::Client;
-
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
-
-
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Client for connecting back to the authmilter server
+our $VERSION = '2.20200302'; # VERSION
+use Mail::Milter::Authentication::Net::Milter;
 use Data::Dumper;
 use Digest::MD5 qw{ md5_base64 };
 use Email::Simple;
-use English qw{ -no_match_vars };
 
-use Mail::Milter::Authentication::Net::Milter;
-use Mail::Milter::Authentication::Config qw{ get_config };
 
 
 sub new {
@@ -120,7 +118,6 @@ sub r { ## no critic [Subroutines::RequireArgUnpacking]
             warn Dumper $result;
         }
     }
-    return;
 }
 
 
@@ -141,7 +138,6 @@ sub insert_header {
         $i++;
     }
     $self->{'header_pairs'} = \@header_pairs;
-    return;
 }
 
 
@@ -176,7 +172,6 @@ sub replace_header {
         }
     }
     $self->{'header_pairs'} = \@header_pairs;
-    return;
 }
 
 
@@ -186,7 +181,6 @@ sub add_header {
     push @header_pairs, $header;
     push @header_pairs, $value;
     $self->{'header_pairs'} = \@header_pairs;
-    return;
 }
 
 
@@ -245,7 +239,6 @@ sub load_mail {
     my $message_object = Email::Simple->new( $mail_data );
     $self->{'message_object'} = $message_object;
     $self->{'header_pairs'}   = \@header_pairs;
-    return;
 }
 
 
@@ -335,7 +328,6 @@ sub process {
     }
 
     $self->{'result'} =  $self->{'message_object'}->as_string();
-    return;
 }
 
 
@@ -355,11 +347,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Client
+Mail::Milter::Authentication::Client - Client for connecting back to the authmilter server
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 SYNOPSIS
 
