@@ -1,12 +1,14 @@
 package Mail::Milter::Authentication::Config;
 # ABSTRACT: Load config files for Authentication Milter
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
-
-use Mail::Milter::Authentication;
-use Module::Load;
-use Module::Loaded;
+##use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Common configuration handling
+our $VERSION = '2.20200302'; # VERSION
+use English;
+use JSON;
+use TOML;
 
 use Exporter qw{ import };
 our @EXPORT_OK = qw{
@@ -15,9 +17,6 @@ our @EXPORT_OK = qw{
   default_config
 };
 
-use JSON;
-use TOML;
-
 
 our $PREFIX = '/etc';
 our $IDENT  = 'authentication_milter';
@@ -56,6 +55,7 @@ sub default_config {
         'handlers'                        => {}
     };
 
+    require Mail::Milter::Authentication;
     my $installed_handlers = Mail::Milter::Authentication::get_installed_handlers();
     foreach my $handler ( @$installed_handlers ) {
         my $handler_module = 'Mail::Milter::Authentication::Handler::' . $handler;
@@ -83,8 +83,6 @@ sub set_config {
     my $protocol = $config->{'protocol'} || 'milter';
     $config->{'protocol'} = $protocol;
     $CONFIG = $config;
-
-    return;
 }
 
 
@@ -210,7 +208,7 @@ Mail::Milter::Authentication::Config - Load config files for Authentication Milt
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 SYNOPSIS
 
@@ -256,7 +254,6 @@ will be called with $config as the argument.g
 
     sub process_config {
         my ( $self, $config ) = @_;
-        return;
     }
 
     1;
