@@ -1,13 +1,30 @@
 package Mail::Milter::Authentication::Constants;
 # ABSTRACT: Define and export useful constants
+use 5.20.0;
 use strict;
 use warnings;
+##use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Common constants
+our $VERSION = '2.20200302'; # VERSION
 use base 'Exporter';
-our $VERSION = '2.20200206'; # VERSION
 
 
 ## no critic [Modules::ProhibitAutomaticExportation]
 
+# Syslog Constants
+
+use constant LOG_DEBUG   => 7;
+use constant LOG_INFO    => 6;
+use constant LOG_NOTICE  => 5;
+use constant LOG_WARNING => 4;
+use constant LOG_ERR     => 3;
+use constant LOG_CRIT    => 2;
+use constant LOG_ALERT   => 1;
+use constant LOG_EMERG   => 0;
+use constant LOG_MAIL    => 16;
+
+# Sendmail Constants
+
 use constant SMFIA_UNKNOWN      => 'U';
 use constant SMFIA_UNIX         => 'L';
 use constant SMFIA_INET         => '4';
@@ -73,6 +90,15 @@ use constant SMFI_V2_ACTS       => SMFI_V1_ACTS|SMFIF_CHGHDRS;
 use constant SMFI_CURR_ACTS     => SMFI_V2_ACTS;
 
 our @EXPORT = qw(
+    LOG_DEBUG
+    LOG_INFO
+    LOG_NOTICE
+    LOG_WARNING
+    LOG_ERR
+    LOG_CRIT
+    LOG_ALERT
+    LOG_EMERG
+    LOG_MAIL
     SMFIA_UNKNOWN
     SMFIA_UNIX
     SMFIA_INET
@@ -134,7 +160,6 @@ our @EXPORT = qw(
 our @EXPORT_OK = ( @EXPORT );
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT_OK ] );
 
-
 1;
 
 __END__
@@ -149,11 +174,11 @@ Mail::Milter::Authentication::Constants - Define and export useful constants
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 SYNOPSIS
 
-Constants defined here are used in the sendmail milter protocol.
+Constants defined here are used in the sendmail milter protocol
 
 =head1 DESCRIPTION
 
