@@ -1,7 +1,10 @@
 package Mail::Milter::Authentication::Exception;
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Class representing an exception
+our $VERSION = '2.20200302'; # VERSION
 
 
 sub new {
@@ -21,11 +24,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Exception
+Mail::Milter::Authentication::Exception - Class representing an exception
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 CONSTRUCTOR
 
