@@ -1,7 +1,10 @@
 package Mail::Milter::Authentication::HTDocs;
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Load and serve static files via the in-built http server.
+our $VERSION = '2.20200302'; # VERSION
 
 
 
@@ -70,11 +73,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::HTDocs
+Mail::Milter::Authentication::HTDocs - Load and serve static files via the in-built http server.
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
