@@ -1,27 +1,21 @@
 package Mail::Milter::Authentication::Handler;
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
-
-
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler superclass
+our $VERSION = '2.20200302'; # VERSION
+use Mail::Milter::Authentication::Exception;
+use Mail::Milter::Authentication::Resolver;
+use Date::Format qw{ time2str };
 use Digest::MD5 qw{ md5_hex };
-use English qw{ -no_match_vars };
-use Clone qw{ clone };
-use Mail::SPF;
 use MIME::Base64;
+use Mail::SPF;
 use Net::DNS::Resolver;
 use Net::IP;
-use Sys::Syslog qw{:standard :macros};
 use Sys::Hostname;
 use Time::HiRes qw{ ualarm gettimeofday };
 
-use Mail::Milter::Authentication::Constants qw { :all };
-use Mail::Milter::Authentication::Config;
-use Mail::Milter::Authentication::Exception;
-use Mail::Milter::Authentication::Resolver;
-use Mail::AuthenticationResults 1.20180328;
-use Mail::AuthenticationResults::Header;
-use Mail::AuthenticationResults::Header::AuthServID;
 
 our $TestResolver; # For Testing
 
@@ -40,9 +34,8 @@ sub get_version {
     my ( $self ) = @_;
     {
         no strict 'refs'; ## no critic;
-        return ${ ref( $self ) . "::VERSION" }; # no critic;
+        return ${ ref( $self ) . "::VERSION" } // 'unknown'; # no critic;
     }
-    return;
 }
 
 
@@ -64,7 +57,6 @@ sub get_json {
 sub metric_register {
     my ( $self, $id, $help ) = @_;
     $self->{'thischild'}->{'metric'}->register( $id, $help, $self->{'thischild'} );
-    return;
 }
 
 
@@ -74,13 +66,14 @@ sub metric_count {
     $count = 1 if ! defined $count;
 
     my $metric = $self->{'thischild'}->{'metric'};
+    $metric->set_handler( $self );
     $metric->count({
         'count_id' => $count_id,
         'labels'   => $labels,
         'server'   => $self->{'thischild'},
         'count'    => $count,
     });
-    return;
+    $metric->set_handler( undef );
 }
 
 
@@ -90,13 +83,14 @@ sub metric_set {
     die 'Must set value in metric_set call' if ! defined $value;
 
     my $metric = $self->{'thischild'}->{'metric'};
+    $metric->set_handler( $self );
     $metric->set({
         'gauge_id' => $gauge_id,
         'labels'   => $labels,
         'server'   => $self->{'thischild'},
         'value'    => $value,
     });
-    return;
+    $metric->set_handler( undef );
 }
 
 
@@ -104,7 +98,6 @@ sub metric_send {
     my ( $self ) = @_;
     # NOOP
     # TODO Deprecate and remove
-    return;
 }
 
 
@@ -187,7 +180,6 @@ sub top_setup_callback {
         $self->metric_count( 'time_microseconds_total', { 'callback' => 'setup', 'handler' => $handler }, $self->get_microseconds_since( $start_time ) );
     }
     $self->status('postsetup');
-    return;
 }
 
 
@@ -203,11 +195,11 @@ sub is_exception_type {
 
 sub handle_exception {
     my ( $self, $exception ) = @_;
+    return if ! defined $exception;
     my $Type = $self->is_exception_type( $exception );
     return if ! $Type;
     die $exception if $Type eq 'Timeout';
     #my $Text = $exception->{ 'Text' } || 'Unknown';
-    return;
 }
 
 
@@ -233,7 +225,6 @@ sub set_alarm {
     else {
         $top_handler->{ 'timeout_at' } = $self->get_microseconds() + ( $microseconds );
     }
-    return;
 }
 
 
@@ -251,7 +242,6 @@ sub set_handler_alarm {
         $self->dbgout( 'Handler tmeout set', $microseconds, LOG_DEBUG );
         ualarm( $microseconds );
     }
-    return;
 }
 
 
@@ -265,7 +255,6 @@ sub reset_alarm {
         die Mail::Milter::Authentication::Exception->new({ 'Type' => 'Timeout', 'Text' => 'Reset check timeout' });
     }
     ualarm( $remaining );
-    return;
 }
 
 
@@ -274,7 +263,6 @@ sub clear_overall_timeout {
     $self->dbgout( 'Overall timeout', 'Clear', LOG_DEBUG );
     my $top_handler = $self->get_top_handler();
     delete $top_handler->{ 'overall_timeout' };
-    return;
 }
 
 
@@ -283,7 +271,6 @@ sub set_overall_timeout {
     my $top_handler = $self->get_top_handler();
     $self->dbgout( 'Overall timeout', $microseconds, LOG_DEBUG );
     $top_handler->{ 'overall_timeout' } = $self->get_microseconds() + $microseconds;
-    return;
 }
 
 
@@ -380,7 +367,6 @@ sub _remap_ip_and_helo {
             }
         }
     }
-    return;
 }
 
 
@@ -393,7 +379,6 @@ sub remap_connect_callback {
         $self->dbgout( 'RemappedConnect', $self->{'raw_ip_object'}->ip() . ' > ' . $ip->ip(), LOG_DEBUG );
     }
     $self->{'ip_object'} = $ip;
-    return;
 }
 
 
@@ -408,7 +393,6 @@ sub top_metrics_callback {
             $self->log_error( 'Metrics callback error ' . $error );
         }
     };
-    return;
 }
 
 
@@ -439,8 +423,7 @@ sub top_connect_callback {
             eval{ $self->get_handler($handler)->connect_callback( $hostname, $ip ); };
             if ( my $error = $@ ) {
                 $self->handle_exception( $error );
-                $self->log_error( 'Connect callback error ' . $error );
-                $self->exit_on_close();
+                $self->exit_on_close( 'Connect callback error ' . $error );
                 $self->tempfail_on_error();
                 $self->metric_count( 'callback_error_total', { 'stage' => 'connect', 'handler' => $handler } );
             }
@@ -451,14 +434,13 @@ sub top_connect_callback {
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'Connect callback error ' . $type . ' - ' . $error->{ 'Text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'connect', 'type' => $type } );
+            $self->exit_on_close( 'Connect callback error ' . $type . ' - ' . $error->{ 'Text' } );
         }
         else {
-            $self->log_error( 'Connect callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'connect' } );
+            $self->exit_on_close( 'Connect callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
     $self->status('postconnect');
@@ -485,7 +467,6 @@ sub remap_helo_callback {
 
         $self->{'helo_name'} = $helo_host;
     }
-    return;
 }
 
 
@@ -515,8 +496,7 @@ sub top_helo_callback {
                 eval{ $self->get_handler($handler)->helo_callback($helo_host); };
                 if ( my $error = $@ ) {
                     $self->handle_exception( $error );
-                    $self->log_error( 'HELO callback error ' . $error );
-                    $self->exit_on_close();
+                    $self->exit_on_close( 'HELO callback error ' . $error );
                     $self->tempfail_on_error();
                     $self->metric_count( 'callback_error_total', { 'stage' => 'helo', 'handler' => $handler } );
                 }
@@ -532,14 +512,13 @@ sub top_helo_callback {
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'HELO error ' . $type . ' - ' . $error->{ 'Text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'helo', 'type' => $type } );
+            $self->exit_on_close( 'HELO error ' . $type . ' - ' . $error->{ 'Text' } );
         }
         else {
-            $self->log_error( 'HELO callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'helo' } );
+            $self->exit_on_close( 'HELO callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
     $self->status('posthelo');
@@ -567,6 +546,7 @@ sub top_envfrom_callback {
         delete $self->{'auth_headers'};
         delete $self->{'pre_headers'};
         delete $self->{'add_headers'};
+        delete $self->{'suppress_error_emails'};
 
         my $callbacks = $self->get_callbacks( 'envfrom' );
         foreach my $handler ( @$callbacks ) {
@@ -575,8 +555,7 @@ sub top_envfrom_callback {
             eval { $self->get_handler($handler)->envfrom_callback($env_from); };
             if ( my $error = $@ ) {
                 $self->handle_exception( $error );
-                $self->log_error( 'Env From callback error ' . $error );
-                $self->exit_on_close();
+                $self->exit_on_close( 'Env From callback error ' . $error );
                 $self->tempfail_on_error();
                 $self->metric_count( 'callback_error_total', { 'stage' => 'envfrom', 'handler' => $handler } );
             }
@@ -587,14 +566,13 @@ sub top_envfrom_callback {
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'EnvFrom error ' . $type . ' - ' . $error->{ 'Text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'envfrom', 'type' => $type } );
+            $self->exit_on_close( 'Env From error ' . $type . ' - ' . $error->{ 'Text' } );
         }
         else {
-            $self->log_error( 'EnvFrom callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'envfrom' } );
+            $self->exit_on_close( 'Env From callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
     $self->status('postenvfrom');
@@ -625,8 +603,7 @@ sub top_envrcpt_callback {
             eval{ $self->get_handler($handler)->envrcpt_callback($env_to); };
             if ( my $error = $@ ) {
                 $self->handle_exception( $error );
-                $self->log_error( 'Rcpt To callback error ' . $error );
-                $self->exit_on_close();
+                $self->exit_on_close( 'Env Rcpt callback error ' . $error );
                 $self->tempfail_on_error();
                 $self->metric_count( 'callback_error_total', { 'stage' => 'rcptto', 'handler' => $handler } );
             }
@@ -637,14 +614,13 @@ sub top_envrcpt_callback {
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'EnvRcpt error ' . $type . ' - ' . $error->{ 'Text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'rcptto', 'type' => $type } );
+            $self->exit_on_close( 'Env Rcpt callback error ' . $type . ' - ' . $error->{ 'Text' } );
         }
         else {
-            $self->log_error( 'EnvRcpt callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'rcptto' } );
+            $self->exit_on_close( 'Env Rcpt callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
     $self->status('postenvrcpt');
@@ -661,6 +637,11 @@ sub top_header_callback {
     $self->set_return( $self->smfis_continue() );
     $value = q{} if ! defined $value;
     my $config = $self->config();
+
+    if ( $header eq 'X-Authentication-Milter-Error' && $value eq 'Generated Error Report' ) {
+        $self->{'suppress_error_emails'} = 1;
+    }
+
     eval {
         local $SIG{'ALRM'} = sub{ die Mail::Milter::Authentication::Exception->new({ 'Type' => 'Timeout', 'Text' => 'Header callback timeout' }) };
         if ( my $timeout = $self->get_type_timeout( 'content' ) ) {
@@ -677,8 +658,7 @@ sub top_header_callback {
             eval{ $self->get_handler($handler)->header_callback( $header, $value, $original ); };
             if ( my $error = $@ ) {
                 $self->handle_exception( $error );
-                $self->log_error( 'Header callback error ' . $error );
-                $self->exit_on_close();
+                $self->exit_on_close( 'Header callback error ' . $error );
                 $self->tempfail_on_error();
                 $self->metric_count( 'callback_error_total', { 'stage' => 'header', 'handler' => $handler } );
             }
@@ -689,14 +669,13 @@ sub top_header_callback {
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'Header error ' . $type . ' - ' . $error->{ 'text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'header', 'type' => $type } );
+            $self->exit_on_close( 'Header error ' . $type . ' - ' . $error->{ 'text' } );
         }
         else {
-            $self->log_error( 'Header callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'header' } );
+            $self->exit_on_close( 'Header callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
     $self->status('postheader');
@@ -725,8 +704,7 @@ sub top_eoh_callback {
             eval{ $self->get_handler($handler)->eoh_callback(); };
             if ( my $error = $@ ) {
                 $self->handle_exception( $error );
-                $self->log_error( 'EOH callback error ' . $error );
-                $self->exit_on_close();
+                $self->exit_on_close( 'EOH callback error ' . $error );
                 $self->tempfail_on_error();
                 $self->metric_count( 'callback_error_total', { 'stage' => 'eoh', 'handler' => $handler } );
             }
@@ -737,14 +715,13 @@ sub top_eoh_callback {
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'EOH error ' . $type . ' - ' . $error->{ 'text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'eoh', 'type' => $type } );
+            $self->exit_on_close( 'EOH error ' . $type . ' - ' . $error->{ 'text' } );
         }
         else {
-            $self->log_error( 'EOH callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'eoh' } );
+            $self->exit_on_close( 'EOH callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
     $self->dbgoutwrite();
@@ -774,8 +751,7 @@ sub top_body_callback {
             eval{ $self->get_handler($handler)->body_callback( $body_chunk ); };
             if ( my $error = $@ ) {
                 $self->handle_exception( $error );
-                $self->log_error( 'Body callback error ' . $error );
-                $self->exit_on_close();
+                $self->exit_on_close( 'Body callback error ' . $error );
                 $self->tempfail_on_error();
                 $self->metric_count( 'callback_error_total', { 'stage' => 'body', 'handler' => $handler } );
             }
@@ -786,14 +762,13 @@ sub top_body_callback {
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'Body error ' . $type . ' - ' . $error->{ 'text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'body', 'type' => $type } );
+            $self->exit_on_close( 'Body error ' . $type . ' - ' . $error->{ 'text' } );
         }
         else {
-            $self->log_error( 'Body callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'body' } );
+            $self->exit_on_close( 'Body callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
     $self->dbgoutwrite();
@@ -823,8 +798,7 @@ sub top_eom_callback {
             eval{ $self->get_handler($handler)->eom_callback(); };
             if ( my $error = $@ ) {
                 $self->handle_exception( $error );
-                $self->log_error( 'EOM callback error ' . $error );
-                $self->exit_on_close();
+                $self->exit_on_close( 'EOM callback error ' . $error );
                 $self->tempfail_on_error();
                 $self->metric_count( 'callback_error_total', { 'stage' => 'eom', 'handler' => $handler } );
             }
@@ -835,14 +809,13 @@ sub top_eom_callback {
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'EOM error ' . $type . ' - ' . $error->{ 'text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'eom', 'type' => $type } );
+            $self->exit_on_close( 'EOM error ' . $type . ' - ' . $error->{ 'text' } );
         }
         else {
-            $self->log_error( 'EOM callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'eom' } );
+            $self->exit_on_close( 'EOM callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
     $self->apply_policy();
@@ -869,8 +842,6 @@ sub apply_policy {
 
     #use Data::Dumper;
     #print Dumper \@structured_headers;
-
-    return;
 }
 
 
@@ -895,8 +866,7 @@ sub top_abort_callback {
             eval{ $self->get_handler($handler)->abort_callback(); };
             if ( my $error = $@ ) {
                 $self->handle_exception( $error );
-                $self->log_error( 'Abort callback error ' . $error );
-                $self->exit_on_close();
+                $self->exit_on_close( 'Abort callback error ' . $error );
                 $self->tempfail_on_error();
                 $self->metric_count( 'callback_error_total', { 'stage' => 'abort', 'handler' => $handler } );
             }
@@ -907,14 +877,13 @@ sub top_abort_callback {
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'Abort error ' . $type . ' - ' . $error->{ 'text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'abort', 'type' => $type } );
+            $self->exit_on_close( 'Abort error ' . $type . ' - ' . $error->{ 'text' } );
         }
         else {
-            $self->log_error( 'Abort callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'abort' } );
+            $self->exit_on_close( 'Abort callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
     $self->status('postabort');
@@ -946,26 +915,30 @@ sub top_close_callback {
             eval{ $self->get_handler($handler)->close_callback(); };
             if ( my $error = $@ ) {
                 $self->handle_exception( $error );
-                $self->log_error( 'Close callback error ' . $error );
-                $self->exit_on_close();
+                $self->exit_on_close( 'Close callback error ' . $error );
                 $self->tempfail_on_error();
                 $self->metric_count( 'callback_error_total', { 'stage' => 'close', 'handler' => $handler } );
             }
             $self->metric_count( 'time_microseconds_total', { 'callback' => 'close', 'handler' => $handler }, $self->get_microseconds_since( $start_time ) );
             $self->check_timeout();
+
+            my $handler_object = $self->get_handler($handler);
+            foreach my $key ( sort keys $handler_object->%* ) {
+                next if $key eq 'thischild';
+                $self->exit_on_close( 'Handler '.$handler.' did not clean up data for key '.$key.' in close callback' );
+            }
         }
         $self->set_alarm(0);
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'Close error ' . $type . ' - ' . $error->{ 'text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'close', 'type' => $type } );
+            $self->exit_on_close( 'Close error ' . $type . ' - ' . $error->{ 'text' } );
         }
         else {
-            $self->log_error( 'Close callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'close' } );
+            $self->exit_on_close( 'Close callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
     delete $self->{'helo_name'};
@@ -1005,18 +978,15 @@ sub top_addheader_callback {
     };
     if ( my $error = $@ ) {
         if ( my $type = $self->is_exception_type( $error ) ) {
-            $self->log_error( 'AddHeader error ' . $type . ' - ' . $error->{ 'text' } );
             $self->metric_count( 'callback_error_total', { 'stage' => 'addheader', 'type' => $type } );
+            $self->exit_on_close( 'AddHeader error ' . $type . ' - ' . $error->{ 'text' } );
         }
         else {
-            $self->log_error( 'AddHeader callback error ' . $error );
             $self->metric_count( 'callback_error_total', { 'stage' => 'addheader' } );
+            $self->exit_on_close( 'AddHeader callback error ' . $error );
         }
-        $self->exit_on_close();
         $self->tempfail_on_error();
     }
-
-    return;
 }
 
 
@@ -1037,7 +1007,6 @@ sub status {
     else {
         $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':processing(' . $count . ')';
     }
-    return;
 }
 
 
@@ -1064,7 +1033,6 @@ sub handler_config {
 
         return $handler_config;
     }
-    return;
 }
 
 
@@ -1088,7 +1056,6 @@ sub set_return {
     my ( $self, $return ) = @_;
     my $top_handler = $self->get_top_handler();
     $top_handler->{'return_code'} = $return;
-    return;
 }
 
 
@@ -1119,7 +1086,6 @@ sub clear_reject_mail {
     my ( $self ) = @_;
     my $top_handler = $self->get_top_handler();
     delete $top_handler->{'reject_mail'};
-    return;
 }
 
 
@@ -1134,7 +1100,6 @@ sub clear_defer_mail {
     my ( $self ) = @_;
     my $top_handler = $self->get_top_handler();
     delete $top_handler->{'defer_mail'};
-    return;
 }
 
 
@@ -1150,7 +1115,6 @@ sub clear_quarantine_mail {
     my ( $self ) = @_;
     my $top_handler = $self->get_top_handler();
     delete $top_handler->{'quarantine_mail'};
-    return;
 }
 
 
@@ -1192,7 +1156,6 @@ sub set_object_maker {
     my $thischild = $self->{'thischild'};
     return if $thischild->{'object_maker'}->{$name};
     $thischild->{'object_maker'}->{$name} = $ref;
-    return;
 }
 
 
@@ -1249,7 +1212,6 @@ sub set_object {
         'object'  => $object,
         'destroy' => $destroy,
     };
-    return;
 }
 
 
@@ -1271,7 +1233,6 @@ sub destroy_object {
     return if ! $thischild->{'object'}->{$name}->{'destroy'};
     $self->dbgout( 'Object destroyed', $name, LOG_DEBUG );
     delete $thischild->{'object'}->{$name};
-    return;
 }
 
 
@@ -1283,15 +1244,17 @@ sub destroy_all_objects {
     {
         $self->destroy_object( $name );
     }
-    return;
 }
 
 
 sub exit_on_close {
-    my ( $self ) = @_;
+    my ( $self, $error ) = @_;
+    $error = 'Generic exit_on_close requested' if ! $error;
+    $self->log_error( $error );
     my $top_handler = $self->get_top_handler();
     $top_handler->{'exit_on_close'} = 1;
-    return;
+    $top_handler->{'exit_on_close_error'} = 'Exit on close requested' if ! exists $top_handler->{'exit_on_close_error'};
+    $top_handler->{'exit_on_close_error'} .= "\n$error";
 }
 
 
@@ -1304,7 +1267,6 @@ sub reject_mail {
     }
     my $top_handler = $self->get_top_handler();
     $top_handler->{'reject_mail'} = $reason;
-    return;
 }
 
 
@@ -1312,7 +1274,6 @@ sub quarantine_mail {
     my ( $self, $reason ) = @_;
     my $top_handler = $self->get_top_handler();
     $top_handler->{'quarantine_mail'} = $reason;
-    return;
 }
 
 
@@ -1325,7 +1286,6 @@ sub defer_mail {
     }
     my $top_handler = $self->get_top_handler();
     $top_handler->{'defer_mail'} = $reason;
-    return;
 }
 
 
@@ -1333,7 +1293,6 @@ sub clear_all_symbols {
     my ( $self ) = @_;
     my $top_handler = $self->get_top_handler();
     delete $top_handler->{'symbols'};
-    return;
 }
 
 
@@ -1355,8 +1314,6 @@ sub clear_symbols {
             'C' => $connect_symbols,
         };
     }
-
-    return;
 }
 
 
@@ -1371,7 +1328,6 @@ sub set_symbol {
         $top_handler->{'symbols'}->{$code} = {};
     }
     $top_handler->{'symbols'}->{$code}->{$key} = $value;;
-    return;
 }
 
 
@@ -1387,7 +1343,6 @@ sub get_symbol {
             }
         }
     }
-    return;
 }
 
 
@@ -1418,7 +1373,6 @@ sub tempfail_on_error {
             $self->set_return( $self->smfis_tempfail() );
         }
     }
-    return;
 }
 
 
@@ -1732,6 +1686,11 @@ sub dbgout {
     $key   = q{--} if ! defined $key;
     $value = q{--} if ! defined $value;
 
+    my $thischild = $self->{'thischild'};
+    if ( exists $thischild->{'tracelog'} ) {
+        push $thischild->{'tracelog'}->@*, time2str('%Y:%m:%d %X %z',time) . " $queue_id: $key: $value";
+    }
+
     my $config = $self->config();
     if (
         $priority == LOG_DEBUG
@@ -1771,15 +1730,12 @@ sub dbgout {
     if ( $self->get_symbol('i') ) {
         $self->dbgoutwrite();
     }
-
-    return;
 }
 
 
 sub log_error {
     my ( $self, $error ) = @_;
     $self->dbgout( 'ERROR', $error, LOG_ERR );
-    return;
 }
 
 
@@ -1812,7 +1768,6 @@ sub dbgoutwrite {
     $self->handle_exception( $@ );  # Not usually called within an eval, however we shouldn't
                                     # ever get a Timeout (for example) here, so it is safe to
                                     # pass to handle_exception anyway.
-    return;
 }
 
 
@@ -1961,8 +1916,6 @@ sub add_headers {
             $self->add_header( $header->{'field'}, $header->{'value'} );
         }
     }
-
-    return;
 }
 
 
@@ -1977,7 +1930,6 @@ sub prepend_header {
         'field' => $field,
         'value' => $value,
       };
-    return;
 }
 
 
@@ -1988,7 +1940,6 @@ sub add_auth_header {
         $top_handler->{'auth_headers'} = [];
     }
     push @{ $top_handler->{'auth_headers'} }, $value;
-    return;
 }
 
 
@@ -2001,7 +1952,6 @@ sub add_c_auth_header {
         $top_handler->{'c_auth_headers'} = [];
     }
     push @{ $top_handler->{'c_auth_headers'} }, $value;
-    return;
 }
 
 
@@ -2016,7 +1966,6 @@ sub append_header {
         'field' => $field,
         'value' => $value,
       };
-    return;
 }
 
 
@@ -2055,7 +2004,6 @@ sub write_packet {
     my ( $self, $type, $data ) = @_;
     my $thischild = $self->{'thischild'};
     $thischild->write_packet( $type, $data );
-    return;
 }
 
 
@@ -2065,7 +2013,6 @@ sub add_header {
     my $config = $self->config();
     return if $config->{'dryrun'};
     $thischild->add_header( $key, $value );
-    return;
 }
 
 
@@ -2075,7 +2022,6 @@ sub insert_header {
     my $config = $self->config();
     return if $config->{'dryrun'};
     $thischild->insert_header( $index, $key, $value );
-    return;
 }
 
 
@@ -2085,7 +2031,6 @@ sub change_header {
     my $config = $self->config();
     return if $config->{'dryrun'};
     $thischild->change_header( $key, $index, $value );
-    return;
 }
 
 1;
@@ -2098,11 +2043,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler
+Mail::Milter::Authentication::Handler - Handler superclass
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
@@ -2217,7 +2162,7 @@ Remove the references to all objects currently stored in the object store.
 
 Certain objects (resolver and spf_server) are not destroyed for performance reasons.
 
-=head2 I<exit_on_close()>
+=head2 I<exit_on_close( $error )>
 
 Exit this child once it has completed, do not process further requests with this child.
 
