@@ -3,10 +3,10 @@ use 5.20.0;
 use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
-# ABSTRACT: Handler class for ARC
-our $VERSION = '2.20210105.2'; # VERSION
+# ABSTRACT: Handler class for ARCx
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-use Mail::DKIM 1.20200824;
+use Mail::DKIM 0.50;
 use Mail::DKIM::ARC::Signer;
 use Mail::DKIM::ARC::Verifier;
 use Mail::DKIM::DNS;
@@ -187,7 +187,7 @@ sub inherit_trusted_spf_results {
                 $result->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'x-arc-domain' )->safe_set_value( $self->{ 'arc_domain'}->{ $instance } ) );
                 $result->add_child( Mail::AuthenticationResults::Header::Comment->new()->safe_set_value( 'Trusted from aar.' . $instance . '.' . $self->{ 'arc_domain' }->{ $instance } ) );
                 $result->orphan();
-                $result->set_key( 'x-arc-spf' );
+                $result->key( 'x-arc-spf' );
                 $self->add_auth_header( $result );
 
             }
@@ -236,7 +236,7 @@ sub inherit_trusted_dkim_results {
                 $result->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'x-arc-domain' )->safe_set_value( $self->{ 'arc_domain'}->{ $instance } ) );
                 $result->add_child( Mail::AuthenticationResults::Header::Comment->new()->safe_set_value( 'Trusted from aar.' . $instance . '.' . $self->{ 'arc_domain' }->{ $instance } ) );
                 $result->orphan();
-                $result->set_key( 'x-arc-dkim' );
+                $result->key( 'x-arc-dkim' );
                 $self->add_auth_header( $result );
 
             }
@@ -424,6 +424,7 @@ sub eoh_callback {
             $UseStrict = 0;
         }
         $arc = Mail::DKIM::ARC::Verifier->new( 'Strict' => $UseStrict );
+        # The following requires Mail::DKIM > 0.4
         my $resolver = $self->get_object('resolver');
         Mail::DKIM::DNS::resolver($resolver);
         $self->set_object('arc', $arc, 1);
@@ -659,7 +660,7 @@ sub addheader_callback {
         my $arcseal = Mail::DKIM::ARC::Signer->new(
             Algorithm => $config->{arcseal_algorithm},
             Domain => $config->{arcseal_domain},
-            SrvId => $self->get_my_authserv_id(),
+            SrvId => $self->get_my_hostname(),
             Selector =>  $config->{arcseal_selector},
             Headers => $config->{arcseal_headers},
             # chain value is arc_result from previous seal validation
@@ -759,11 +760,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::ARC - Handler class for ARC
+Mail::Milter::Authentication::Handler::ARC - Handler class for ARCx
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20200302
 
 =head1 DESCRIPTION
 
