@@ -1,10 +1,11 @@
 package Mail::Milter::Authentication::Handler::AddID;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Example handler class
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
-use Sys::Syslog qw{:standard :macros};
 
 sub default_config {
     return {};
@@ -15,7 +16,6 @@ sub eom_callback {
     # On HELO
     my ( $self, $helo_host ) = @_;
     $self->append_header('X-Authentication-Milter','Header added by Authentication Milter');
-    return;
 }
 
 1;
@@ -28,11 +28,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::AddID
+Mail::Milter::Authentication::Handler::AddID - Example handler class
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
