@@ -1,13 +1,12 @@
 package Mail::Milter::Authentication::Handler::AlignedFrom;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler class for Address alignment
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
 use Net::DNS;
-use Sys::Syslog qw{:standard :macros};
-use Mail::AuthenticationResults::Header::Entry;
-use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -47,8 +46,6 @@ sub envfrom_callback {
         $self->{ 'smtp_address'} = lc $email;
         $self->{ 'smtp_domain'} = lc $self->get_domain_from( $email );
     }
-
-    return;
 }
 
 sub header_callback {
@@ -76,18 +73,16 @@ sub header_callback {
         # If there are more than 1 then the result will be set to error in the eom callback
         # Multiple from headers should always set the result to error.
     }
-
-    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
+    delete $self->{ 'envfrom_count' };
     delete $self->{ 'from_header_count' };
     delete $self->{ 'header_address' };
     delete $self->{ 'header_domain' };
     delete $self->{ 'smtp_address' };
     delete $self->{ 'smtp_domain' };
-    return;
 }
 
 # error = multiple from headers present
@@ -175,8 +170,6 @@ sub eom_callback {
     $self->add_auth_header( $header );
 
     $self->metric_count( 'alignedfrom_total', { 'result' => $result } );
-
-    return;
 }
 
 1;
@@ -189,11 +182,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::AlignedFrom
+Mail::Milter::Authentication::Handler::AlignedFrom - Handler class for Address alignment
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
