@@ -1,13 +1,11 @@
 package Mail::Milter::Authentication::Handler::Auth;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler class for SMTP Auth
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
-use Sys::Syslog qw{:standard :macros};
-use Mail::AuthenticationResults::Header::Entry;
-use Mail::AuthenticationResults::Header::SubEntry;
-use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -32,7 +30,6 @@ sub pre_loop_setup {
     if ( $protocol ne 'milter' ) {
         warn 'The Auth handler only works with the milter protocol';
     }
-    return;
 }
 
 sub get_auth_name {
@@ -44,7 +41,6 @@ sub get_auth_name {
 sub connect_callback {
     my ( $self, $hostname, $ip ) = @_;
     $self->{'is_authenticated'} = 0;
-    return;
 }
 
 sub envfrom_callback {
@@ -62,13 +58,11 @@ sub envfrom_callback {
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'auth' )->safe_set_value( 'pass' );
         $self->add_auth_header( $header );
     }
-    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'is_authenticated'};
-    return;
 }
 
 1;
@@ -81,11 +75,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::Auth
+Mail::Milter::Authentication::Handler::Auth - Handler class for SMTP Auth
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
