@@ -4,36 +4,29 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler class for BIMI
-our $VERSION = '2.20210105.2'; # VERSION
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-use Mail::BIMI 2;
+use Mail::BIMI 1.20200214;
 
 sub default_config {
     return {
-        'bimi_options' => {},
-        'rbl_allowlist' => '',
-        'rbl_blocklist' => '',
-        'rbl_no_evidence_allowlist' => '',
-      };
+    };
 }
 
 sub register_metrics {
     return {
         'bimi_total' => 'The number of emails processed for BIMI',
-        'bimi_removed_total' => 'The number BIMI headers removed',
+        'bimi_removed_total' => 'The number BIMI-Location headers removed',
     };
 }
 
 sub remove_bimi_header {
-    my ( $self, $header, $value ) = @_;
-    $self->metric_count( 'bimi_removed_total' );
+    my ( $self, $value ) = @_;
+    $self->metric_count( 'bimi_remove_total' );
     if ( !exists( $self->{'remove_bimi_headers'} ) ) {
-        $self->{'remove_bimi_headers'} = {};
+        $self->{'remove_bimi_headers'} = [];
     }
-    if ( !exists( $self->{'remove_bimi_headers'}->{$header} ) ) {
-        $self->{'remove_bimi_headers'}->{$header} = [];
-    }
-    push @{ $self->{'remove_bimi_headers'}->{$header} }, $value;
+    push @{ $self->{'remove_bimi_headers'} }, $value;
 }
 
 sub envfrom_callback {
@@ -48,27 +41,21 @@ sub header_callback {
 
     # Not sure where this should go in the flow, so it's going here!
     # Which is clearly, or at least probably the wrong place.
-    #
-    foreach my $header_type ( qw{ BIMI-Location BIMI-Indicator} ) {
-        if ( lc $header eq lc $header_type ) {
-            if ( !exists $self->{'bimi_header_index'} ) {
-                $self->{'bimi_header_index'} = {};
-            }
-            if ( !exists $self->{'bimi_header_index'}->{lc $header_type} ) {
-                $self->{'bimi_header_index'}->{lc $header_type} = 0;
-            }
-            $self->{'bimi_header_index'}->{lc $header_type} =
-            $self->{'bimi_header_index'}->{lc $header_type} + 1;
-            $self->remove_bimi_header( $header_type, $self->{'bimi_header_index'}->{lc $header_type} );
-            my $forged_header =
-              "(Received $header_type header removed by "
-              . $self->get_my_hostname()
-              . ')' . "\n"
-              . '    '
-              . $value;
-            $self->append_header( 'X-Received-'.$header_type,
-                $forged_header );
+    if ( lc $header eq 'bimi-location' ) {
+        if ( !exists $self->{'bimi_header_index'} ) {
+            $self->{'bimi_header_index'} = 0;
         }
+        $self->{'bimi_header_index'} =
+        $self->{'bimi_header_index'} + 1;
+        $self->remove_bimi_header( $self->{'bimi_header_index'} );
+        my $forged_header =
+          '(Received BIMI-Location header removed by '
+          . $self->get_my_hostname()
+          . ')' . "\n"
+          . '    '
+          . $value;
+        $self->append_header( 'X-Received-BIMI-Location',
+            $forged_header );
     }
 
     return if ( $self->is_local_ip_address() );
@@ -115,18 +102,11 @@ sub eom_callback {
     my ($self) = @_;
     my $config = $self->handler_config();
 
-    if ( $config->{rbl_allowlist} && $config->{rbl_blocklist} ) {
-        $self->dbgout( 'BIMI Error', 'Cannot specify both rbl_allowlist and rbl_blocklist', LOG_DEBUG );
-        return;
-    }
-
     # Again, not sure where this should go, so it's going here.
     if ( exists( $self->{'remove_bimi_headers'} ) ) {
-        foreach my $header_type ( sort keys %{ $self->{'remove_bimi_headers'} } ) {
-            foreach my $header ( reverse @{ $self->{'remove_bimi_headers'}->{$header_type} } ) {
-                $self->dbgout( 'RemoveBIMIHeader', "$header_type $header", LOG_DEBUG );
-                $self->change_header( $header_type, $header, q{} );
-            }
+        foreach my $header ( reverse @{ $self->{'remove_bimi_headers'} } ) {
+            $self->dbgout( 'RemoveBIMILocationHeader', $header, LOG_DEBUG );
+            $self->change_header( 'BIMI-Location', $header, q{} );
         }
     }
 
@@ -141,24 +121,8 @@ sub eom_callback {
         my $DMARCResults = $self->get_object( 'dmarc_results' );
         if ( ! $DMARCResults ) {
 
-            my $failure_type = 'temperror';
-            my $top_handler = $self->get_top_handler();
-            my @auth_headers;
-            if ( exists( $top_handler->{'auth_headers'} ) ) {
-                @auth_headers = ( @auth_headers, @{ $top_handler->{'auth_headers'} } );
-            }
-            if (@auth_headers) {
-                foreach my $auth_header (@auth_headers) {
-                    next unless $auth_header->key eq 'dmarc';
-                    if ( $auth_header->value eq 'permerror' ) {
-                        $failure_type = 'permerror';
-                        last;
-                    }
-                }
-            }
-
             $self->log_error( 'BIMI Error No DMARC Results object');
-            my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'bimi' )->safe_set_value( $failure_type );
+            my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'bimi' )->safe_set_value( 'temperror' );
             $header->add_child( Mail::AuthenticationResults::Header::Comment->new()->safe_set_value( 'Internal DMARC error' ) );
             $self->add_auth_header( $header );
             $self->{ 'header_added' } = 1;
@@ -176,6 +140,7 @@ sub eom_callback {
                 return;
             }
             else {
+                # If Multiple DMARC results is OK then... foreach my $DMARCResult ( @$DMARCResults ) {
                 my $DMARCResult = clone $DMARCResults->[0]; # Clone so we can modify without breaking reporting data
 
                 ## Consider ARC
@@ -266,75 +231,28 @@ sub eom_callback {
                     }
                 }
 
-                my $Skip;
-                if ( $config->{rbl_allowlist} ) {
-                    my $OrgDomain = $self->get_object('dmarc')->get_organizational_domain($Domain);
-                    unless ( $self->rbl_check_domain( $OrgDomain, $config->{'rbl_allowlist'} ) ) {
-                        $self->dbgout( 'BIMISkip', 'Not on allowlist', LOG_INFO );
-                        $Skip = 'Local policy; not allowed';
-                    }
-                }
-                elsif ( $config->{rbl_blocklist} ) {
-                    my $OrgDomain = $self->get_object('dmarc')->get_organizational_domain($Domain);
-                    if ( $self->rbl_check_domain( $OrgDomain, $config->{'rbl_blocklist'} ) ) {
-                        $self->dbgout( 'BIMISkip', 'On blocklist', LOG_INFO );
-                        $Skip = 'Local policy; blocked';
-                    }
-                }
-
-                my %Options;
-                $Options{options} = $config->{'bimi_options'} if exists $config->{'bimi_options'};
-                $Options{resolver} = $self->get_object( 'resolver' );
-                $Options{dmarc_object} = $self->get_object('dmarc');
-                $Options{spf_object} = $RelevantSPFResult if $RelevantSPFResult;
-                $Options{domain} = $Domain;
-                $Options{selector} = $Selector;
-                my $BIMI = Mail::BIMI->new(%Options);
+                my $BIMI = Mail::BIMI->new(
+                    resolver => $self->get_object( 'resolver' ),
+                    dmarc_object => $DMARCResult,
+                    $RelevantSPFResult ? ( spf_object => $RelevantSPFResult ) : (),
+                    domain => $Domain,
+                    selector => $Selector,
+                );
                 $self->{'bimi_object'} = $BIMI; # For testing!
 
-                my $Result;
-                $Result = $BIMI->result() if ! $Skip;
-
-                if ( !$Skip
-                     && $config->{rbl_no_evidence_allowlist}
-                     && $Result->result eq 'pass'
-                     && (
-                       !$BIMI->record->authority
-                       || !$BIMI->record->authority->vmc
-                       || !$BIMI->record->authority->vmc->is_valid
-                     )
-                ) {
-                    my $OrgDomain = $self->get_object('dmarc')->get_organizational_domain($Domain);
-                    unless ( $self->rbl_check_domain( $OrgDomain, $config->{'rbl_no_evidence_allowlist'} ) ) {
-                        $self->dbgout( 'BIMISkip', 'Not on No Evidence Allowlist', LOG_INFO );
-                        $Skip = 'Local policy; not allowed without evidence';
-                    }
+                my $Result = $BIMI->result();
+                my $AuthResults = $Result->get_authentication_results_object();
+                $self->add_auth_header( $AuthResults );
+                $self->{ 'header_added' } = 1;
+                my $Record = $BIMI->record();
+                my $URLList = $Record->locations->location;
+                if ( $Result->result() eq 'pass' ) {
+                    $self->prepend_header( 'BIMI-Location', join( "\n",
+                        'v=BIMI1;',
+                        '    l=' . join( ',', @$URLList ) ) );
                 }
 
-
-                if ( $Skip ) {
-                    my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'bimi' )->safe_set_value( 'skipped' );
-                    $header->add_child( Mail::AuthenticationResults::Header::Comment->new()->safe_set_value( $Skip ) );
-                    $self->add_auth_header( $header );
-                    $self->{ 'header_added' } = 1;
-                    $self->metric_count( 'bimi_total', { 'result' => 'skipped', 'reason' => 'rbl' } );
-                }
-                else {
-                    my $AuthResults = $Result->get_authentication_results_object();
-                    $self->add_auth_header( $AuthResults );
-                    $self->{ 'header_added' } = 1;
-                    my $Record = $BIMI->record();
-                    if ( $Result->result() eq 'pass' ) {
-                        my $Headers = $Result->headers;
-                        if ( $Headers ) {
-                            $self->prepend_header( 'BIMI-Location', $Headers->{'BIMI-Location'} ) if exists $Headers->{'BIMI-Location'} ;
-                            $self->prepend_header( 'BIMI-Indicator', $Headers->{'BIMI-Indicator'} ) if exists $Headers->{'BIMI-Indicator'} ;
-                        }
-                    }
-
-                    $self->metric_count( 'bimi_total', { 'result' => $Result->result() } );
-                }
-                $BIMI->finish;
+                $self->metric_count( 'bimi_total', { 'result' => $Result->result() } );
             }
         }
 
@@ -358,7 +276,7 @@ sub close_callback {
     delete $self->{'remove_bimi_headers'};
     delete $self->{'bimi_object'};
     delete $self->{'bimi_header_index'};
-    delete $self->{'header_added'};
+    delete $self->{ 'header_added' };
 }
 
 1;
@@ -375,7 +293,9 @@ Mail::Milter::Authentication::Handler::BIMI - Handler class for BIMI
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20200302
+
+=head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
@@ -391,14 +311,19 @@ This handler requires the DMARC handler and its dependencies to be installed and
 
         "BIMI" : {                                      | Config for the BIMI Module
                                                         | Requires DMARC
-            "bimi_options" : {},                        | Options to pass into Mail::BIMI->new
-            "rbl_allowlist" : "",                       | Optional RBL Allow list of allowed org domains
-            "rbl_blocklist" : "",                       | Optional RBL Block list of disallowed org domains
-                                                        | Allow and Block list cannot both be present
-            "rbl_no_evidence_allowlist" : "",           | Optonal RBL Allow list of allowed org domains that do NOT require evidence documents
-                                                        | When set, domains not on this list which do not have evidence documents will be 'skipped'
         },
 
+=head1 AUTHORS
+
+Marc Bradshaw E<lt>marc@marcbradshaw.netE<gt>
+
+=head1 COPYRIGHT
+
+Copyright 2018
+
+This library is free software; you may redistribute it and/or
+modify it under the same terms as Perl itself.
+
 =head1 AUTHOR
 
 Marc Bradshaw <marc@marcbradshaw.net>
