@@ -1,19 +1,14 @@
 package Mail::Milter::Authentication::Handler::DMARC;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler class for DMARC
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
-use Data::Dumper;
-use English qw{ -no_match_vars };
-use Net::IP;
-use Sys::Syslog qw{:standard :macros};
 use List::MoreUtils qw{ uniq };
-
 use Mail::DMARC::PurePerl 1.20160612;
-use Mail::AuthenticationResults::Header::Entry;
-use Mail::AuthenticationResults::Header::SubEntry;
-use Mail::AuthenticationResults::Header::Comment;
+use Net::IP;
 
 my $PSL_CHECKED_TIME;
 
@@ -146,7 +141,6 @@ sub pre_loop_setup {
     else {
         $self->{'thischild'}->logerror( 'DMARC Could not preload PSL' );
     }
-    return;
 }
 
 sub pre_fork_setup {
@@ -173,7 +167,6 @@ sub pre_fork_setup {
             $self->{'thischild'}->loginfo( 'DMARC PSL file update checking not available' );
         }
     }
-    return;
 }
 
 sub register_metrics {
@@ -196,8 +189,6 @@ sub metrics_callback {
         $self->metric_set( 'dmarc_reports_total', { 'state' => 'current' }, $current );
         $self->metric_set( 'dmarc_reports_total', { 'state' => 'pending' }, $pending );
     };
-
-    return;
 }
 
 sub _process_arc_dmarc_for {
@@ -480,6 +471,10 @@ sub _process_dmarc_for {
                   $remote_ip //= eval{ $aar->search({ 'isa' => 'entry', 'key' => 'iprev' })->children()->[0]->search({ 'isa' => 'subentry', 'key' => 'policy.iprev'})->children()->[0]->value(); };
                   $self->handle_exception( $@ );
 
+                  $domain //= '';
+                  $selector //= '';
+                  $remote_ip //= '';
+
                   $comment .= ' as['.$instance.'].d='.$domain.' as['.$instance.'].s='.$selector.' remote-ip['.$instance.']='.$remote_ip;
                 }
               }
@@ -602,8 +597,6 @@ sub _process_dmarc_for {
             $self->dbgout( 'DMARCReportTo (skipped)', $rua, LOG_INFO );
         }
     }
-
-    return;
 }
 
 sub get_dmarc_object {
@@ -655,7 +648,6 @@ sub helo_callback {
     my ( $self, $helo_host ) = @_;
     $self->{'helo_name'} = $helo_host;
     $self->{'report_queue'} = [] if ! $self->{'report_queue'};
-    return;
 }
 
 sub envfrom_requires {
@@ -697,8 +689,6 @@ sub envfrom_callback {
     }
 
     $self->{ 'from_headers' } = [];
-
-    return;
 }
 
 sub check_skip_address {
@@ -712,7 +702,6 @@ sub check_skip_address {
             $self->{'skip_report'} = 1;
         }
     }
-    return;
 }
 
 sub envrcpt_callback {
@@ -723,8 +712,6 @@ sub envrcpt_callback {
 
     $self->{ 'env_to' } = $env_to;
     $self->check_skip_address( $env_to );
-
-    return;
 }
 
 sub header_callback {
@@ -769,7 +756,6 @@ sub header_callback {
         }
 
     }
-    return;
 }
 
 sub eom_requires {
@@ -846,8 +832,6 @@ sub eom_callback {
     }
 
     delete $self->{ 'dmarc_ar_headers' };
-
-    return;
 }
 
 sub can_sort_header {
@@ -903,13 +887,11 @@ sub _get_unique_dmarc_headers {
 sub _add_dmarc_header {
     my ( $self, $header ) = @_;
     push @{ $self->{ 'dmarc_ar_headers' } }, $header;
-    return;
 }
 
 sub addheader_callback {
     my $self = shift;
     my $handler = shift;
-    return;
 }
 
 sub _save_aggregate_reports {
@@ -941,7 +923,6 @@ sub _save_aggregate_reports {
         $self->handle_exception( $Error );
         $self->log_error( 'DMARC Report Error ' . $Error );
     }
-    return;
 }
 
 sub close_callback {
@@ -954,12 +935,11 @@ sub close_callback {
     delete $self->{'skip_report'};
     delete $self->{'is_list'};
     delete $self->{'from_header'};
-    delete $self->{'from_heades'};
+    delete $self->{'from_headers'};
     delete $self->{'report_queue'};
     $self->destroy_object('dmarc');
     $self->destroy_object('dmarc_result');
     $self->destroy_object('dmarc_results');
-    return;
 }
 
 1;
@@ -972,11 +952,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::DMARC
+Mail::Milter::Authentication::Handler::DMARC - Handler class for DMARC
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
