@@ -1,13 +1,11 @@
 package Mail::Milter::Authentication::Handler::LocalIP;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler class for Local IP Connections
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
-use Sys::Syslog qw{:standard :macros};
-use Mail::AuthenticationResults::Header::Entry;
-use Mail::AuthenticationResults::Header::SubEntry;
-use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -66,13 +64,11 @@ sub connect_callback {
         $self->{'is_local_ip_address'} = 1;
         $self->metric_count( 'localip_connect_total' );
     }
-    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'is_local_ip_address'};
-    return;
 }
 
 1;
@@ -85,11 +81,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::LocalIP
+Mail::Milter::Authentication::Handler::LocalIP - Handler class for Local IP Connections
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
