@@ -1,13 +1,11 @@
 package Mail::Milter::Authentication::Handler::PTR;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler class for PTR checking
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
-use Sys::Syslog qw{:standard :macros};
-use Mail::AuthenticationResults::Header::Entry;
-use Mail::AuthenticationResults::Header::SubEntry;
-use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -60,8 +58,6 @@ sub helo_callback {
     $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'policy.ptr' )->safe_set_value( $domains ) );
     $self->add_c_auth_header( $header );
     $self->metric_count( 'ptr_total', { 'result' => $result} );
-
-    return;
 }
 
 1;
@@ -74,11 +70,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::PTR
+Mail::Milter::Authentication::Handler::PTR - Handler class for PTR checking
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
