@@ -1,14 +1,11 @@
 package Mail::Milter::Authentication::Handler::SPF;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler class for SPF
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
-use Sys::Syslog qw{:standard :macros};
-use Mail::AuthenticationResults::Header::Entry;
-use Mail::AuthenticationResults::Header::SubEntry;
-use Mail::AuthenticationResults::Header::Comment;
-
 use Mail::SPF;
 
 sub default_config {
@@ -50,7 +47,6 @@ sub setup_callback {
             'destroy' => 0,
         };
     });
-    return;
 }
 
 sub register_metrics {
@@ -71,7 +67,6 @@ sub helo_callback {
     my ( $self, $helo_host ) = @_;
     $self->{'failmode'} = 0;
     $self->{'helo_name'} = $helo_host;
-    return;
 }
 
 sub envfrom_callback {
@@ -125,6 +120,10 @@ sub envfrom_callback {
         );
 
         my $spf_result = $spf_server->process($spf_request);
+        my $spf_results = $self->get_object('spf_results');
+        $spf_results = [] if ! $spf_results;
+        push @$spf_results, $spf_result;
+        $self->set_object('spf_results',$spf_results,1);
 
         my $result_code = $spf_result->code();
 
@@ -150,6 +149,10 @@ sub envfrom_callback {
                                 'helo_identity'    => $self->{'helo_name'},
                             );
                             $spf_result = $spf_server->process($spf_request);
+                            my $spf_results = $self->get_object('spf_results');
+                            $spf_results = [] if ! $spf_results;
+                            push @$spf_results, $spf_result;
+                            $self->set_object('spf_results',$spf_results,1);
                             $result_code = $spf_result->code();
                         }
                     }
@@ -194,8 +197,6 @@ sub envfrom_callback {
         $self->add_auth_header($header);
         $self->metric_count( 'spf_total', { 'result' => 'error' } );
     }
-
-    return;
 }
 
 sub close_callback {
@@ -205,7 +206,7 @@ sub close_callback {
     delete $self->{'dmarc_result'};
     delete $self->{'failmode'};
     delete $self->{'helo_name'};
-    return;
+    $self->destroy_object('spf_results');
 }
 
 1;
@@ -218,11 +219,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::SPF
+Mail::Milter::Authentication::Handler::SPF - Handler class for SPF
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
