@@ -1,10 +1,11 @@
 package Mail::Milter::Authentication::Handler::Sanitize;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler class for Removing headers
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
-use Sys::Syslog qw{:standard :macros};
 
 sub default_config {
     return {
@@ -62,7 +63,6 @@ sub remove_auth_header {
         $self->{'remove_auth_headers'} = [];
     }
     push @{ $self->{'remove_auth_headers'} }, $index;
-    return;
 }
 
 sub get_headers_to_remove {
@@ -84,8 +84,6 @@ sub envfrom_callback {
         };
     }
     $self->{'header_hash'} = $headers;
-
-    return;
 }
 
 sub header_callback {
@@ -136,8 +134,6 @@ sub header_callback {
                 $forged_header );
         }
     }
-
-    return;
 }
 
 sub eom_callback {
@@ -161,8 +157,6 @@ sub eom_callback {
             }
         }
     }
-
-    return;
 }
 
 sub close_callback {
@@ -170,7 +164,6 @@ sub close_callback {
     delete $self->{'remove_auth_headers'};
     delete $self->{'auth_result_header_index'};
     delete $self->{'header_hash'};
-    return;
 }
 
 1;
@@ -183,11 +176,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::Sanitize
+Mail::Milter::Authentication::Handler::Sanitize - Handler class for Removing headers
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
