@@ -1,17 +1,13 @@
 package Mail::Milter::Authentication::Handler::SenderID;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler class for SenderID
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
-use Sys::Syslog qw{:standard :macros};
-use Mail::AuthenticationResults::Header::Entry;
-use Mail::AuthenticationResults::Header::SubEntry;
-use Mail::AuthenticationResults::Header::Comment;
-
-use Mail::SPF;
-
 use Mail::Milter::Authentication::Handler::SPF;
+use Mail::SPF;
 
 sub default_config {
     return {
@@ -42,7 +38,6 @@ sub register_metrics {
 sub helo_callback {
     my ( $self, $helo_host ) = @_;
     $self->{'helo_name'} = $helo_host;
-    return;
 }
 
 sub envfrom_callback {
@@ -51,7 +46,6 @@ sub envfrom_callback {
     return if ( $self->is_trusted_ip_address() );
     return if ( $self->is_authenticated() );
     delete $self->{'from_header'};
-    return;
 }
 
 sub header_callback {
@@ -62,7 +56,6 @@ sub header_callback {
     if ( lc $header eq 'from' ) {
         $self->{'from_header'} = $value;
     }
-    return;
 }
 
 sub eoh_callback {
@@ -127,14 +120,12 @@ sub eoh_callback {
         $self->add_auth_header($header);
         return;
     }
-    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'from_header'};
     delete $self->{'helo_name'};
-    return;
 }
 
 1;
@@ -147,11 +138,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::SenderID
+Mail::Milter::Authentication::Handler::SenderID - Handler class for SenderID
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
