@@ -1,13 +1,11 @@
 package Mail::Milter::Authentication::Handler::TLS;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler class for TLS
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
-use Sys::Syslog qw{:standard :macros};
-use Mail::AuthenticationResults::Header::Entry;
-use Mail::AuthenticationResults::Header::SubEntry;
-use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {};
@@ -32,14 +30,12 @@ sub pre_loop_setup {
     if ( $protocol eq 'smtp' ) {
         warn 'When in smtp mode, the TLS handler requires the MTA to write TLS data into the first Received header.';
     }
-    return;
 }
 
 sub connect_callback {
     my ( $self ) = @_;
     # Reset state on a connection
     delete $self->{'is_encrypted'};
-    return;
 }
 
 sub envfrom_callback {
@@ -82,7 +78,6 @@ sub envfrom_callback {
     else {
         $self->{'is_encrypted'} = 0;
     }
-    return;
 }
 
 sub header_callback {
@@ -132,8 +127,6 @@ sub header_callback {
 
         $self->add_auth_header( $header );
     }
-
-    return;
 }
 
 sub eoh_callback {
@@ -142,14 +135,12 @@ sub eoh_callback {
     return if $protocol ne 'smtp';
     return if defined $self->{'is_encrypted'};
     $self->{'is_encrypted'} = 0;
-    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'first_header_read'};
     delete $self->{'is_encrypted'};
-    return;
 }
 
 1;
@@ -162,11 +153,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::TLS
+Mail::Milter::Authentication::Handler::TLS - Handler class for TLS
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
