@@ -1,14 +1,12 @@
 package Mail::Milter::Authentication::Handler::TrustedIP;
+use 5.20.0;
 use strict;
 use warnings;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Handler class for Trusted IP addresses
+our $VERSION = '2.20200302'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20200206'; # VERSION
-
 use Net::IP;
-use Sys::Syslog qw{:standard :macros};
-use Mail::AuthenticationResults::Header::Entry;
-use Mail::AuthenticationResults::Header::SubEntry;
-use Mail::AuthenticationResults::Header::Comment;
 
 sub default_config {
     return {
@@ -60,13 +58,11 @@ sub connect_callback {
         $self->{'is_trusted_ip_address'} = 1;
         $self->metric_count( 'trustedip_connect_total' );
     }
-    return;
 }
 
 sub close_callback {
     my ( $self ) = @_;
     delete $self->{'is_trusted_ip_address'};
-    return;
 }
 
 1;
@@ -79,11 +75,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Handler::TrustedIP
+Mail::Milter::Authentication::Handler::TrustedIP - Handler class for Trusted IP addresses
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
