@@ -1,58 +1,129 @@
 package Mail::Milter::Authentication::Metric;
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
-
-
-use English qw{ -no_match_vars };
-use JSON;
-use TOML;
-use Prometheus::Tiny::Shared;
-use Mail::Milter::Authentication::Config qw{ get_config };
-use Mail::Milter::Authentication::Metric::Grafana;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Class for metrics generation
+our $VERSION = '2.20200302'; # VERSION
 use Mail::Milter::Authentication::HTDocs;
+use Mail::Milter::Authentication::Metric::Grafana;
+use File::Temp;
+use Prometheus::Tiny::Shared 0.011;
+use TOML;
+
+
 
 
 sub new {
-    my ( $class ) = @_;
+    my ( $class, $thischild ) = @_;
     my $self = {};
-    $self->{'counter'}    = {};
-    $self->{'help'}       = {};
-    $self->{'start_time'} = time;
-    $self->{'queue'}      = [];
+    $self->{counter}            = {};
+    $self->{help}               = {};
+    $self->{start_time}         = time;
+    $self->{registered_metrics} = [];
+    $self->{thischild}          = $thischild;
+    bless $self, $class;
+
+    $self->set_handler( undef );
 
     my $config = get_config();
 
-    $self->{'enabled'} = defined( $config->{'metric_port'} ) ? 1
-                       : defined( $config->{'metric_connection'} ) ? 1
-                       : 0;
+    $self->{enabled} = defined( $config->{metric_port} ) ? 1
+                     : defined( $config->{metric_connection} ) ? 1
+                     : 0;
 
-    if ( $self->{'enabled'} ) {
-        my $cache_args = {};
-        $cache_args->{'init_file'} = 1;
-        if ( defined( $config->{'metric_tempfile'} ) ) {
-            $cache_args->{'share_file'} = $config->{'metric_tempfile'};
+    return $self;
+}
+
+
+sub set_handler {
+    my ( $self, $handler ) = @_;
+    $self->{handler} = $handler;
+}
+
+
+sub handle_exception {
+    my ( $self, $exception ) = @_;
+    return if ! defined $exception;
+    return if ! defined $self->{handler};
+    $self->{handler}->handle_exception($exception);
+}
+
+
+sub dbgout {
+    my ( $self, $key, $value, $priority ) = @_;
+    if ( defined ( $self->{handler} ) ) {
+        $self->{handler}->dbgout($key,$value,$priority);
+    }
+    elsif ( $priority == LOG_DEBUG ) {
+        $self->{thischild}->logdebug( "$key: $value" );
+    }
+    elsif ( $priority == LOG_INFO || $priority == LOG_NOTICE ) {
+        $self->{thischild}->loginfo( "$key: $value" );
+    }
+    else {
+        $self->{thischild}->logerror( "$key: $value" );
+    }
+}
+
+
+sub prom {
+    my ( $self ) = @_;
+    my $config = get_config();
+
+    my $metric_tempfile;
+    if ( exists( $self->{metric_tempfile} ) ) {
+        $metric_tempfile = $self->{metric_tempfile};
+    }
+    else {
+        if ( defined( $config->{metric_tempfile} ) ) {
+            $metric_tempfile = $config->{metric_tempfile};
         }
-        $self->{'prom'} = Prometheus::Tiny::Shared->new( cache_args => $cache_args );
-        $self->{'prom'}->declare( 'authmilter_uptime_seconds_total', help => 'Number of seconds since server startup', type => 'counter' );
-        $self->{'prom'}->declare( 'authmilter_processes_waiting', help => 'The number of authentication milter processes in a waiting state', type => 'gauge' );
-        $self->{'prom'}->declare( 'authmilter_processes_processing', help => 'The number of authentication milter processes currently processing data', type => 'gauge' );
-        $self->{'prom'}->declare( 'authmilter_version', help => 'Running versions', type => 'gauge' );
+        if ( ! $metric_tempfile ) {
+            my $file_temp = File::Temp->new( UNLINK => 0, SUFFIX => '.sqlite' );
+            $metric_tempfile = $file_temp->filename;
+        }
+        $self->{metric_tempfile} = $metric_tempfile;
     }
 
-    bless $self, $class;
-    return $self;
+    my $prom = $self->{prom};
+    # Invalidate if the file does not exist!
+    if ( ! -e $metric_tempfile ) {
+        $prom = undef;
+    }
+
+    if ( ! $prom ) {
+        $self->dbgout( 'Metrics', "Setup new metrics file $metric_tempfile", LOG_DEBUG );
+        $prom = eval{ Prometheus::Tiny::Shared->new(filename => $metric_tempfile, init_file => 1) };
+        $self->handle_exception($@);
+        if ( $prom ) {
+            $self->{metric_tempfile} = $metric_tempfile;
+            $prom->declare( 'authmilter_uptime_seconds_total', help => 'Number of seconds since server startup', type => 'counter' );
+            $prom->declare( 'authmilter_processes_waiting', help => 'The number of authentication milter processes in a waiting state', type => 'gauge' );
+            $prom->declare( 'authmilter_processes_processing', help => 'The number of authentication milter processes currently processing data', type => 'gauge' );
+            $prom->declare( 'authmilter_version', help => 'Running versions', type => 'gauge' );
+        }
+        else {
+            $self->dbgout( 'Metrics', "Failed to setup new metrics file $metric_tempfile", LOG_ERR );
+        }
+    }
+    $self->{prom} = $prom;
+
+    return $prom;
 }
 
 
 sub set_versions {
     my ( $self, $server ) = @_;
-    $self->{'prom'}->set( 'authmilter_version', 1, { version => $Mail::Milter::Authentication::VERSION, module => 'core', ident => $self->clean_label( $Mail::Milter::Authentication::Config::IDENT ) });
-    foreach my $Handler ( sort keys %{ $server->{ 'handler' } } ) {
+    return if ! $self->{enabled};
+    return if ! $self->prom;
+    $self->dbgout( 'Metrics', "Setting up versioning metrics", LOG_DEBUG );
+    $self->prom->set( 'authmilter_version', 1, { version => $Mail::Milter::Authentication::VERSION, module => 'core', ident => $self->clean_label( $Mail::Milter::Authentication::Config::IDENT ) });
+    foreach my $Handler ( sort keys %{ $server->{handler} } ) {
         next if $Handler eq '_Handler';
-        $self->{'prom'}->set( 'authmilter_version', 1, { version => $server->{ 'handler' }->{ $Handler }->get_version(), module => $Handler, ident => $self->clean_label( $Mail::Milter::Authentication::Config::IDENT ) });
+        eval{ $self->prom->set( 'authmilter_version', 1, { version => $server->{handler}->{ $Handler }->get_version(), module => $Handler, ident => $self->clean_label( $Mail::Milter::Authentication::Config::IDENT ) }) };
+        $self->handle_exception($@);
     }
-    return;
 }
 
 
@@ -60,7 +131,7 @@ sub set_versions {
 sub get_timeout {
     my ( $self ) = @_;
     my $config = get_config();
-    return $config->{ 'metric_timeout' } || 5;
+    return $config->{metric_timeout} || 5;
 }
 
 
@@ -77,12 +148,13 @@ sub clean_label {
 
 sub count {
     my ( $self, $args ) = @_;
-    return if ( ! $self->{ 'enabled' } );
+    return if ! $self->{enabled};
+    return if ! $self->prom;
 
-    my $count_id = $args->{ 'count_id' };
-    my $labels   = $args->{ 'labels' };
-    my $server   = $args->{ 'server' };
-    my $count    = $args->{ 'count' };
+    my $count_id = $args->{count_id};
+    my $labels   = $args->{labels};
+    my $server   = $args->{server};
+    my $count    = $args->{count};
 
     $count = 1 if ! defined $count;
 
@@ -97,21 +169,22 @@ sub count {
 
     $clean_labels->{ident} = $self->clean_label( $Mail::Milter::Authentication::Config::IDENT );
 
-    eval{ $self->{prom}->add( 'authmilter_' . $count_id, $count, $clean_labels ); };
-    ## TODO catch and re-throw timeouts
+    $self->dbgout( 'Metrics', "Counting $count_id:$count:".join(',',map {"$_=".$clean_labels->{$_}} (sort keys %$clean_labels) ), LOG_DEBUG );
 
-    return;
+    eval{ $self->prom->add( 'authmilter_' . $count_id, $count, $clean_labels ); };
+    $self->handle_exception($@);
 }
 
 
 sub set {
     my ( $self, $args ) = @_;
-    return if ( ! $self->{ 'enabled' } );
+    return if ! $self->{enabled};
+    return if ! $self->prom;
 
-    my $gauge_id = $args->{ 'gauge_id' };
-    my $labels   = $args->{ 'labels' };
-    my $server   = $args->{ 'server' };
-    my $value    = $args->{ 'value' };
+    my $gauge_id = $args->{gauge_id};
+    my $labels   = $args->{labels};
+    my $server   = $args->{server};
+    my $value    = $args->{value};
 
     die 'metric set must define value' if ! defined $value;
 
@@ -126,22 +199,40 @@ sub set {
 
     $clean_labels->{ident} = $self->clean_label( $Mail::Milter::Authentication::Config::IDENT );
 
-    eval{ $self->{prom}->set( 'authmilter_' . $gauge_id, $value, $clean_labels ); };
-    ## TODO catch and re-throw timeouts
+    $self->dbgout( 'Metrics', "Setting $gauge_id:$value:".join(',',map {"$_=".$clean_labels->{$_}} (sort keys %$clean_labels) ), LOG_DEBUG );
 
-    return;
+    eval{ $self->prom->set( 'authmilter_' . $gauge_id, $value, $clean_labels ); };
+    $self->handle_exception($@);
 }
 
 
 sub send { ## no critic
     my ( $self, $server ) = @_;
-    return;
 }
 
 
 sub register_metrics {
     my ( $self, $hash ) = @_;
-    return if ( ! $self->{ 'enabled' } );
+    return if ! $self->{enabled};
+    return if ! $self->prom;
+    push @{$self->{registered_metrics}}, $hash;
+    $self->_register_metrics( $hash );
+}
+
+
+sub re_register_metrics {
+    my ( $self ) = @_;
+    return if ! $self->{enabled};
+    return if ! $self->prom;
+    foreach my $metric ( @{$self->{registered_metrics}} ) {
+        $self->_register_metrics( $metric );
+    }
+}
+
+sub _register_metrics {
+    my ( $self, $hash ) = @_;
+    return if ! $self->{enabled};
+    return if ! $self->prom;
 
     foreach my $metric ( keys %$hash ) {
         my $data = $hash->{ $metric };
@@ -154,38 +245,36 @@ sub register_metrics {
         else {
             $help = $data;
         }
-        $self->{prom}->declare( 'authmilter_' . $metric, help => $help, type => $type);
-        $self->{prom}->set( 'authmilter_' . $metric,0, { ident => $self->clean_label( $Mail::Milter::Authentication::Config::IDENT ) });
+        $self->prom->declare( 'authmilter_' . $metric, help => $help, type => $type);
+        $self->prom->add( 'authmilter_' . $metric,0, { ident => $self->clean_label( $Mail::Milter::Authentication::Config::IDENT ) });
     }
-    return;
 }
 
 
 sub master_metric_update {
     my ( $self, $server ) = @_;
-    return if ( ! $self->{ 'enabled' } );
+    return if ! $self->{enabled};
+    return if ! $self->prom;
 
     eval {
         foreach my $type ( qw { waiting processing } ) {
-            $self->{prom}->set('authmilter_processes_' . $type, $server->{'server'}->{'tally'}->{ $type }, { ident => $self->clean_label( $Mail::Milter::Authentication::Config::IDENT ) });
+            $self->prom->set('authmilter_processes_' . $type, $server->{server}->{tally}->{$type}, { ident => $self->clean_label( $Mail::Milter::Authentication::Config::IDENT ) });
         }
     };
-
-    return;
 }
 
 
 sub child_handler {
     my ( $self, $server ) = @_;
-    return if ( ! $self->{ 'enabled' } );
+    return if ! $self->{enabled};
 
     my $config = get_config();
 
     eval {
-        local $SIG{'ALRM'} = sub{ die "Timeout\n" };
+        local $SIG{ALRM} = sub{ die "Timeout\n" };
         alarm( $self->get_timeout() );
 
-        my $socket = $server->{'server'}->{'client'};
+        my $socket = $server->{server}->{client};
         my $req;
 
         $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':metrics';
@@ -218,13 +307,20 @@ sub child_handler {
         }
 
         if ( $request_uri eq '/metrics' ) {
-            $server->{'handler'}->{'_Handler'}->top_metrics_callback();
-            $self->{prom}->set( 'authmilter_uptime_seconds_total', time - $self->{'start_time'}, { ident => $self->clean_label( $Mail::Milter::Authentication::Config::IDENT ) });
+            if ( $self->prom ) {
+                $server->{handler}->{_Handler}->top_metrics_callback();
+                $self->prom->set( 'authmilter_uptime_seconds_total', time - $self->{start_time}, { ident => $self->clean_label( $Mail::Milter::Authentication::Config::IDENT ) });
+            }
 
             print $socket "HTTP/1.0 200 OK\n";
             print $socket "Content-Type: text/plain\n";
             print $socket "\n";
-            print $socket $self->{prom}->format();
+            if ( $self->prom ) {
+                print $socket $self->prom->format();
+            }
+            else {
+                print $socket '# Metrics unavailable';
+            }
 
         }
         elsif ( $request_uri eq '/' ){
@@ -251,9 +347,9 @@ sub child_handler {
     <h2>Installed Handlers</h2>
     <div class="spaceAfter">};
 
-    foreach my $Handler ( sort keys %{ $server->{ 'handler' } } ) {
+    foreach my $Handler ( sort keys %{ $server->{handler} } ) {
         next if $Handler eq '_Handler';
-        print $socket ' <span class="handler">' . $Handler . ' (' . $server->{ 'handler' }->{ $Handler }->get_version(). ')</span> ';
+        print $socket ' <span class="handler">' . $Handler . ' (' . $server->{handler}->{ $Handler }->get_version(). ')</span> ';
     }
 
     print $socket qq{
@@ -263,7 +359,7 @@ sub child_handler {
     <table class="callbacksTable">};
 
     foreach my $stage ( qw{ setup connect helo envfrom envrcpt header eoh body eom abort close addheader } ) {
-        my $callbacks = $server->{ 'handler' }->{ '_Handler' }->get_callbacks( $stage );
+        my $callbacks = $server->{handler}->{_Handler}->get_callbacks( $stage );
         print $socket "<tr><td>$stage</td><td>" . join( ' ', map{ "<span class=\"handler\">$_</span>" } @$callbacks ) . "</td></tr>";
     }
 
@@ -271,11 +367,11 @@ sub child_handler {
 
     <h2>Connection/Config Details</h2>
     <ul>};
-    print $socket '<li>Protocol: ' . $config->{'protocol'} . '</li>';
-    my $connections = $config->{'connections'};
-    $connections->{'default'} = { 'connection' => $config->{'connection'} };
+    print $socket '<li>Protocol: ' . $config->{protocol} . '</li>';
+    my $connections = $config->{connections};
+    $connections->{default} = { connection => $config->{connection} };
     foreach my $connection ( sort keys %$connections ) {
-        print $socket '<li>' . $connection . ': ' . $connections->{ $connection }->{ 'connection' } . '</li>'
+        print $socket '<li>' . $connection . ': ' . $connections->{ $connection }->{connection} . '</li>'
     }
     print $socket qq{
         <li>Effective config (<a href="/config/toml">toml</a>/<a href="/config/json">json</a>)</li>
@@ -334,8 +430,6 @@ sub child_handler {
 
         alarm( 0 );
     };
-
-    return;
 }
 
 1;
@@ -348,11 +442,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Metric
+Mail::Milter::Authentication::Metric - Class for metrics generation
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
@@ -369,6 +463,18 @@ This object is used to store, modify, and report metrics.
 
 =head1 METHODS
 
+=head2 I<set_handler($handler)>
+
+Set a reference to the current handler
+
+=head2 I<handle_exception($exception)>
+
+If we have a handler, then pass any exception to that handlers exception handling
+
+=head2 I<prom()>
+
+Return the prom object if available
+
 =head2 I<set_versions( $server )>
 
 Setup version metrics
@@ -420,6 +526,11 @@ Called from the master process in the setup phase.
 
 Expects a hashref of metric description, keyed on metric name.
 
+=head2 I<re_register_metric()>
+
+Re-register currently registered metrics to ensure backend
+metadata is correct
+
 =head2 I<master_metric_update( $server )>
 
 Called in the master process to periodically update some metrics
@@ -428,6 +539,13 @@ Called in the master process to periodically update some metrics
 
 Handle a metrics or http request in the child process.
 
+=head1 LOGGING METHODS
+
+=head2 I<dbgout( $key, $value, $priority )>
+
+Pass arguments along to the dbgout method of the handler if we have one
+or log via the Mail::Milter::Authentication object if we do not.
+
 =head1 AUTHOR
 
 Marc Bradshaw <marc@marcbradshaw.net>
