@@ -1,9 +1,10 @@
 package Mail::Milter::Authentication::Metric::Grafana;
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
-
-use JSON;
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Class for Grafana dashboards
+our $VERSION = '2.20200302'; # VERSION
 
 sub get_json {
     my ( $self, $file ) = @_;
@@ -68,11 +69,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Metric::Grafana
+Mail::Milter::Authentication::Metric::Grafana - Class for Grafana dashboards
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
