@@ -3,7 +3,8 @@ package Mail::Milter::Authentication::Net::Milter;
 use strict;
 use Carp;
 use vars qw($DEBUG);
-our $VERSION = '2.20200206'; # VERSION
+# ABSTRACT: Local modified copy of Net::Milter
+our $VERSION = '2.20200302'; # VERSION
 $DEBUG=0;
 
 use constant PROTOCOL_NEGATION => 0;
@@ -718,11 +719,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Net::Milter
+Mail::Milter::Authentication::Net::Milter - Local modified copy of Net::Milter
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 SYNOPSIS
 
