@@ -3,7 +3,7 @@ use 5.20.0;
 use strict;
 use warnings;
 # ABSTRACT: Setup system wide pragmas
-our $VERSION = '2.20210105.2'; # VERSION
+our $VERSION = '2.20200302'; # VERSION
 use base 'Exporter';
 require feature;
 use open ':std', ':encoding(UTF-8)';
@@ -14,8 +14,7 @@ use Mail::Milter::Authentication::Config;
 use Carp;
 use Clone;
 use English;
-use File::Slurp;
-use JSON::XS;
+use JSON;
 use Module::Load;
 use Module::Loaded;
 use Mail::AuthenticationResults 1.20200108;
@@ -32,14 +31,13 @@ sub import {
   feature->import($_)               for ( qw{ postderef signatures } );
   warnings->unimport($_)            for ( qw{ experimental::postderef experimental::signatures } );
 
-  Mail::Milter::Authentication::Config->import::into(scalar caller,qw{ set_config get_config setup_config });
+  Mail::Milter::Authentication::Config->import::into(scalar caller,qw{ set_config get_config });
   Mail::Milter::Authentication::Constants->import::into(scalar caller);
 
   Carp->import::into(scalar caller);
   Clone->import::into(scalar caller,qw{ clone });
   English->import::into(scalar caller);
-  File::Slurp->import::into(scalar caller, qw{ read_file write_file } );
-  JSON::XS->import::into(scalar caller);
+  JSON->import::into(scalar caller);
   Module::Load->import::into(scalar caller);
   Module::Loaded->import::into(scalar caller);
 }
@@ -58,7 +56,7 @@ Mail::Milter::Authentication::Pragmas - Setup system wide pragmas
 
 =head1 VERSION
 
-version 2.20210105.2
+version 2.20200302
 
 =head1 AUTHOR
 
