@@ -1,13 +1,12 @@
 package Mail::Milter::Authentication::Protocol::Milter;
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
-
-use English qw{ -no_match_vars };
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Milter protocol handling
+our $VERSION = '2.20200302'; # VERSION
 use Net::IP;
 
-use Mail::Milter::Authentication::Constants qw{ :all };
-
 sub register_metrics {
     return {
         'mail_processed_total' => 'Number of emails processed',
@@ -41,8 +40,6 @@ sub protocol_process_request {
         $self->milter_process_command( $command, $data );
 
     }
-
-    return;
 }
 
 sub milter_process_command {
@@ -152,7 +149,10 @@ sub milter_process_command {
     }
 
     if (defined $returncode) {
-        if ( $returncode == SMFIS_CONTINUE ) {
+        if ( $returncode eq SMFIR_QUARANTINE ) {
+            # NOP
+        }
+        elsif ( $returncode == SMFIS_CONTINUE ) {
             $returncode = SMFIR_CONTINUE;
         }
         elsif ( $returncode == SMFIS_TEMPFAIL ) {
@@ -222,8 +222,6 @@ sub milter_process_command {
             }
         }
     }
-
-    return;
 }
 
 sub milter_process_connect {
@@ -294,7 +292,6 @@ sub add_header {
         . $value
         . "\0"
     );
-    return;
 }
 
 sub change_header {
@@ -307,7 +304,6 @@ sub change_header {
         . $value
         . "\0"
     );
-    return;
 }
 
 sub insert_header {
@@ -319,7 +315,6 @@ sub insert_header {
         . $value
         . "\0"
     );
-    return;
 }
 
 sub write_packet {
@@ -331,7 +326,6 @@ sub write_packet {
     $socket->syswrite($len);
     $socket->syswrite($code);
     $socket->syswrite($data);
-    return;
 }
 
 1;
@@ -344,11 +338,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Protocol::Milter
+Mail::Milter::Authentication::Protocol::Milter - Milter protocol handling
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 SYNOPSIS
 
@@ -411,11 +405,6 @@ Receive a new command from the protocol stream and process it.
 
 =back
 
-=head1 DEPENDENCIES
-
-  English
-  Net::IP
-
 =head1 AUTHOR
 
 Marc Bradshaw <marc@marcbradshaw.net>
