@@ -1,20 +1,17 @@
 package Mail::Milter::Authentication::Protocol::SMTP;
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
-
-use English qw{ -no_match_vars };
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: SMTP protocol handling
+our $VERSION = '2.20200302'; # VERSION
+use Digest::MD5 qw{ md5_hex };
 use Email::Date::Format qw{ email_date };
 use File::Temp;
-use IO::Socket;
 use IO::Socket::INET;
 use IO::Socket::UNIX;
-use Digest::MD5 qw{ md5_hex };
+use IO::Socket;
 use Net::IP;
-use Sys::Syslog qw{:standard :macros};
-
-use Mail::Milter::Authentication::Constants qw{ :all };
-use Mail::Milter::Authentication::Config;
 
 sub register_metrics {
     return {
@@ -47,7 +44,6 @@ sub smtp_status {
     my ( $self, $status ) = @_;
     my $smtp = $self->{'smtp'};
     $PROGRAM_NAME = $Mail::Milter::Authentication::Config::IDENT . ':' . $status . '(' . $self->{'count'} . '.' . $smtp->{'count'} . ')';
-    return;
 }
 
 sub smtp_init {
@@ -68,8 +64,6 @@ sub smtp_init {
     $handler->dbgout( 'SMTP Transaction count', $self->{'count'} . '.' . $smtp->{'count'} , LOG_INFO );
 
     $smtp->{'init_required'} = 0;
-
-    return;
 }
 
 sub protocol_process_request {
@@ -208,7 +202,6 @@ sub protocol_process_request {
     $self->close_destination_socket();
 
     delete $self->{'smtp'};
-    return;
 }
 
 sub smtp_queue_id {
@@ -255,7 +248,6 @@ sub smtp_command_lhlo {
     print $socket "250-PIPELINING\r\n";
     print $socket "250-ENHANCEDSTATUSCODES\r\n";
     print $socket "250 8BITMIME\r\n";
-    return;
 }
 
 sub smtp_command_ehlo {
@@ -281,7 +273,6 @@ sub smtp_command_ehlo {
     print $socket "250-PIPELINING\r\n";
     print $socket "250-ENHANCEDSTATUSCODES\r\n";
     print $socket "250 8BITMIME\r\n";
-    return;
 }
 
 sub smtp_command_helo {
@@ -298,7 +289,6 @@ sub smtp_command_helo {
     }
     $smtp->{'helo_host'} = command_param( $command,5 );
     print $socket "250 " . $smtp->{'server_name'} . " Hi " . $smtp->{'helo_host'} . "\r\n";
-    return;
 }
 
 sub smtp_command_xforward {
@@ -344,7 +334,6 @@ sub smtp_command_xforward {
         }
     }
     print $socket "250 2.0.0 Ok\r\n";
-    return;
 }
 
 sub smtp_command_rset {
@@ -370,8 +359,15 @@ sub smtp_command_rset {
     $self->smtp_init();
 
     my $smtp_conf = $self->get_smtp_config();
+
     my $handler = $self->{'handler'}->{'_Handler'};
-        if ( $smtp_conf->{'pipeline_limit'} ) {
+    if ( $handler->{'exit_on_close'} ) {
+            $smtp->{'last_command'} = 1;
+            $handler->dbgout( 'EXIT ON CLOSE REQUESTED', 'closing on RSET', LOG_INFO );
+            print $socket "421 4.3.2 Pipeline limit reached\r\n";
+            return;
+    }
+    if ( $smtp_conf->{'pipeline_limit'} ) {
         my $count = $smtp->{'count'};
         my $limit = $smtp_conf->{'pipeline_limit'};
         if ( $count > $limit ) {
@@ -382,8 +378,6 @@ sub smtp_command_rset {
         }
     }
     print $socket "250 2.0.0 Ok\r\n";
-
-    return;
 }
 
 sub smtp_command_mailfrom {
@@ -472,8 +466,6 @@ sub smtp_command_mailfrom {
     else {
         print $socket "451 4.0.2 Connection - That's not right\r\n";
     }
-
-    return;
 }
 
 sub smtp_command_rcptto {
@@ -508,8 +500,6 @@ sub smtp_command_rcptto {
     else {
         print $socket "451 4.0.3 That's not right\r\n";
     }
-
-    return;
 }
 
 sub smtp_command_data {
@@ -787,7 +777,11 @@ sub smtp_command_data {
     $smtp->{'string'}           = q{};
     $self->{'handler'}->{'_Handler'}->top_close_callback();
     $smtp->{'init_required'}    = 1;
-    return;
+
+    if ( $handler->{'exit_on_close'} ) {
+            $smtp->{'last_command'} = 1;
+            $handler->dbgout( 'EXIT ON CLOSE REQUESTED', 'NO MORE SMTP', LOG_INFO );
+    }
 }
 
 sub smtp_insert_received_header {
@@ -823,7 +817,6 @@ sub smtp_insert_received_header {
     );
 
     splice @{ $smtp->{'headers'} }, 0, 0, 'Received: '. $value;
-    return;
 }
 
 sub smtp_forward_to_destination {
@@ -971,7 +964,6 @@ sub close_destination_socket {
     $self->send_smtp_packet( $sock, 'QUIT', '221' ) || return;
     $sock->close();
     delete $smtp->{'destination_sock'};
-    return;
 }
 
 sub send_smtp_packet {
@@ -1025,7 +1017,6 @@ sub add_header {
     my $smtp = $self->{'smtp'};
     $value =~ s/\015?\012/\015\012/g;
     push @{ $smtp->{'headers'} } , "$header: $value";
-    return;
 }
 
 sub change_header {
@@ -1058,8 +1049,6 @@ sub change_header {
             #untested.
         }
     }
-
-    return;
 }
 
 sub insert_header {
@@ -1067,7 +1056,6 @@ sub insert_header {
     my $smtp = $self->{'smtp'};
     $value =~ s/\015?\012/\015\012/g;
     splice @{ $smtp->{'headers'} }, $index - 1, 0, "$key: $value";
-    return;
 }
 
 1;
@@ -1080,11 +1068,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Protocol::SMTP
+Mail::Milter::Authentication::Protocol::SMTP - SMTP protocol handling
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 SYNOPSIS
 
@@ -1207,12 +1195,6 @@ Update the process name status line
 
 =back
 
-=head1 DEPENDENCIES
-
-  English
-  Digest::MD5
-  Net::IP
-
 =head1 AUTHOR
 
 Marc Bradshaw <marc@marcbradshaw.net>
