@@ -1,7 +1,10 @@
 package Mail::Milter::Authentication::Resolver;
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: DNS Recolver methods
+our $VERSION = '2.20200302'; # VERSION
 use base 'Net::DNS::Resolver';
 use Scalar::Util qw{ weaken };
 
@@ -21,7 +24,6 @@ use Scalar::Util qw{ weaken };
 sub clear_error_cache {
     my $self = shift;
     $self->{ _timedout } = {};
-    return;
 }
 
 sub _do { ## no critic
@@ -109,11 +111,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Resolver
+Mail::Milter::Authentication::Resolver - DNS Recolver methods
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 DESCRIPTION
 
