@@ -1,26 +1,23 @@
 package Mail::Milter::Authentication::Tester;
+use 5.20.0;
 use strict;
 use warnings;
-our $VERSION = '2.20200206'; # VERSION
-
-our @ISA = qw{ Exporter }; ## no critic
-our @EXPORT = qw{ start_milter stop_milter get_metrics test_metrics smtp_process smtp_process_multi milter_process smtpput send_smtp_packet smtpcat }; ## no critic
-
-use Net::DNS::Resolver::Mock 1.20171219;
-use Test::More;
-use Test::File::Contents;
-
+use Mail::Milter::Authentication::Pragmas;
+# ABSTRACT: Class used for testing
+our $VERSION = '2.20200302'; # VERSION
+use Mail::Milter::Authentication;
+use Mail::Milter::Authentication::Client;
+use Mail::Milter::Authentication::Protocol::Milter;
+use Mail::Milter::Authentication::Protocol::SMTP;
 use Cwd qw{ cwd };
 use IO::Socket::INET;
 use IO::Socket::UNIX;
-use JSON;
-use Module::Load;
+use Net::DNS::Resolver::Mock 1.20171219;
+use Test::File::Contents;
+use Test::More;
 
-use Mail::Milter::Authentication;
-use Mail::Milter::Authentication::Client;
-use Mail::Milter::Authentication::Config;
-use Mail::Milter::Authentication::Protocol::Milter;
-use Mail::Milter::Authentication::Protocol::SMTP;
+our @ISA = qw{ Exporter }; ## no critic
+our @EXPORT = qw{ start_milter stop_milter get_metrics test_metrics smtp_process smtp_process_multi milter_process smtpput send_smtp_packet smtpcat }; ## no critic
 
 my $base_dir = cwd();
 
@@ -131,19 +128,19 @@ sub test_metrics {
 
             foreach my $key ( sort keys %$data ) {
                 if ( $key =~ /seconds_total/ ) {
-                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $key" );
+                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $expected $key" );
                 }
                 elsif ( $key =~ /microseconds_sum/ ) {
-                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $key" );
+                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $expected $key" );
                 }
                 elsif ( $key =~ /authmilter_forked_children_total/ ) {
-                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $key" );
+                    is( $metrics->{ $key } > 0, $data->{ $key } > 0, "Metrics $expected $key" );
                 }
                 elsif ( $key =~ /authmilter_processes_/) {
-                    is( $metrics->{ $key } > -1, $data->{ $key } > -1, "Metrics $key" );
+                    is( $metrics->{ $key } > -1, $data->{ $key } > -1, "Metrics $expected $key" );
                 }
                 else {
-                    is( $metrics->{ $key }, $data->{ $key }, "Metrics $key" );
+                    is( $metrics->{ $key }, $data->{ $key }, "Metrics $expected $key" );
                 }
             }
 
@@ -175,8 +172,6 @@ sub test_metrics {
         }
 
     };
-
-    return;
 }
 
 sub smtp_process {
@@ -222,8 +217,6 @@ sub smtp_process {
     else {
         is( $return, 1, 'SMTP Put Returned ok' );
     }
-
-    return;
 }
 
 sub smtp_process_multi {
@@ -285,8 +278,6 @@ sub smtp_process_multi {
     waitpid( $cat_pid,0 );
 
     files_eq_or_diff( 'data/example/' . $args->{'dest'}, 'tmp/result/' . $args->{'dest'}, 'smtp ' . $args->{'desc'} );
-
-    return;
 }
 
 sub milter_process {
@@ -312,8 +303,6 @@ sub milter_process {
     });
 
     files_eq_or_diff( 'data/example/' . $args->{'dest'}, 'tmp/result/' . $args->{'dest'}, 'milter ' . $args->{'desc'} );
-
-    return;
 }
 
 sub smtpput {
@@ -568,7 +557,6 @@ sub client {
 
     }
     waitpid( $pid, 0 );
-    return;
 }
 
 1;
@@ -581,11 +569,11 @@ __END__
 
 =head1 NAME
 
-Mail::Milter::Authentication::Tester
+Mail::Milter::Authentication::Tester - Class used for testing
 
 =head1 VERSION
 
-version 2.20200206
+version 2.20200302
 
 =head1 AUTHOR
 
